# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from datetime import datetime

from typing import NoReturn
from typing import Optional

from pyVmomi.VmomiSupport import ManagedObject
from pyVmomi.VmomiSupport import long

from pyVmomi.vim import Datastore
from pyVmomi.vim import Task

from pyVmomi.vmodl import DynamicData

from pyVmomi.vim.encryption import CryptoKeyId

class DatastoreBrowser(ManagedObject):
   class FileInfo(DynamicData):
      class Details(DynamicData):
         fileType: bool
         fileSize: bool
         modification: bool
         fileOwner: bool

      path: str
      friendlyName: Optional[str] = None
      fileSize: Optional[long] = None
      modification: Optional[datetime] = None
      owner: Optional[str] = None

   class Query(DynamicData):
      pass

   class VmConfigQuery(Query):
      class Filter(DynamicData):
         matchConfigVersion: list[int] = []
         encrypted: Optional[bool] = None

      class Details(DynamicData):
         configVersion: bool
         encryption: Optional[bool] = None

      filter: Optional[Filter] = None
      details: Optional[Details] = None

   class TemplateVmConfigQuery(VmConfigQuery):
      pass

   class VmDiskQuery(Query):
      class Filter(DynamicData):
         diskType: list[type] = []
         matchHardwareVersion: list[int] = []
         controllerType: list[type] = []
         thin: Optional[bool] = None
         encrypted: Optional[bool] = None

      class Details(DynamicData):
         diskType: bool
         capacityKb: bool
         hardwareVersion: bool
         controllerType: Optional[bool] = None
         diskExtents: Optional[bool] = None
         thin: Optional[bool] = None
         encryption: Optional[bool] = None
         sectorFormat: Optional[bool] = None

      filter: Optional[Filter] = None
      details: Optional[Details] = None

   class FolderQuery(Query):
      pass

   class VmSnapshotQuery(Query):
      pass

   class IsoImageQuery(Query):
      pass

   class FloppyImageQuery(Query):
      pass

   class VmNvramQuery(Query):
      pass

   class VmLogQuery(Query):
      pass

   class VmConfigInfo(FileInfo):
      class VmConfigEncryptionInfo(DynamicData):
         keyId: Optional[CryptoKeyId] = None

      configVersion: Optional[int] = None
      encryption: Optional[VmConfigEncryptionInfo] = None

   class TemplateVmConfigInfo(VmConfigInfo):
      pass

   class VmDiskInfo(FileInfo):
      class VmDiskEncryptionInfo(DynamicData):
         keyId: Optional[CryptoKeyId] = None

      diskType: Optional[type] = None
      capacityKb: Optional[long] = None
      hardwareVersion: Optional[int] = None
      controllerType: Optional[type] = None
      diskExtents: list[str] = []
      thin: Optional[bool] = None
      encryption: Optional[VmDiskEncryptionInfo] = None
      sectorFormat: Optional[str] = None

   class FolderInfo(FileInfo):
      pass

   class VmSnapshotInfo(FileInfo):
      pass

   class IsoImageInfo(FileInfo):
      pass

   class FloppyImageInfo(FileInfo):
      pass

   class VmNvramInfo(FileInfo):
      pass

   class VmLogInfo(FileInfo):
      pass

   class SearchSpec(DynamicData):
      query: list[Query] = []
      details: Optional[FileInfo.Details] = None
      searchCaseInsensitive: Optional[bool] = None
      matchPattern: list[str] = []
      sortFoldersFirst: Optional[bool] = None

   class SearchResults(DynamicData):
      datastore: Optional[Datastore] = None
      folderPath: Optional[str] = None
      file: list[FileInfo] = []

   @property
   def datastore(self) -> list[Datastore]: ...
   @property
   def supportedType(self) -> list[Query]: ...

   def Search(self, datastorePath: str, searchSpec: Optional[SearchSpec]) -> Task: ...
   def SearchSubFolders(self, datastorePath: str, searchSpec: Optional[SearchSpec]) -> Task: ...
   def DeleteFile(self, datastorePath: str) -> NoReturn: ...



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import Optional

from pyVmomi.VmomiSupport import ManagedObject

from pyVmomi.vim import Task
from pyVmomi.vim import VirtualMachine

from pyVmomi.vim.option import OptionValue

from pyVmomi.vim.vm.customization import Specification

from pyVmomi.vim.vm.guest import GuestAuthentication

class GuestCustomizationManager(ManagedObject):
   def Customize(self, vm: VirtualMachine, auth: GuestAuthentication, spec: Specification, configParams: list[OptionValue]) -> Task: ...
   def StartNetwork(self, vm: VirtualMachine, auth: GuestAuthentication) -> Task: ...
   def AbortCustomization(self, vm: VirtualMachine, auth: GuestAuthentication) -> Task: ...



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import Optional

from pyVmomi.vim.cluster import SiteFaultDomainConfig
from pyVmomi.vim.cluster import VsanIscsiTargetServiceConfig
from pyVmomi.vim.cluster import VsanPerfsvcConfig

from pyVmomi.vim.vsan import DataEfficiencyConfig
from pyVmomi.vim.vsan import DataEncryptionConfig
from pyVmomi.vim.vsan import DataInTransitEncryptionConfig
from pyVmomi.vim.vsan import DatastoreConfig
from pyVmomi.vim.vsan import FileServiceConfig
from pyVmomi.vim.vsan import MetricsConfig
from pyVmomi.vim.vsan import RdmaConfig
from pyVmomi.vim.vsan import ResyncIopsInfo
from pyVmomi.vim.vsan import SnapServiceConfig
from pyVmomi.vim.vsan import VcRemoteVsanServerClusterConfig
from pyVmomi.vim.vsan import VsanDatastoreDefaultPolicySelectionConfig
from pyVmomi.vim.vsan import VsanDeconvergedNetConfig
from pyVmomi.vim.vsan import VsanEsaConfigInfo
from pyVmomi.vim.vsan import VsanExtendedConfig
from pyVmomi.vim.vsan import VsanHealthConfigSpec
from pyVmomi.vim.vsan import VsanPMemConfig
from pyVmomi.vim.vsan import VsanUnmapConfig
from pyVmomi.vim.vsan import VsanVumConfig
from pyVmomi.vim.vsan import XVCDatastoreConfig

from pyVmomi.vim.vsan.cluster import ConfigInfo

class ConfigInfoEx(ConfigInfo):
   dataEfficiencyConfig: Optional[DataEfficiencyConfig] = None
   resyncIopsLimitConfig: Optional[ResyncIopsInfo] = None
   iscsiConfig: Optional[VsanIscsiTargetServiceConfig] = None
   dataEncryptionConfig: Optional[DataEncryptionConfig] = None
   extendedConfig: Optional[VsanExtendedConfig] = None
   datastoreConfig: Optional[DatastoreConfig] = None
   perfsvcConfig: Optional[VsanPerfsvcConfig] = None
   unmapConfig: Optional[VsanUnmapConfig] = None
   vumConfig: Optional[VsanVumConfig] = None
   fileServiceConfig: Optional[FileServiceConfig] = None
   metricsConfig: Optional[MetricsConfig] = None
   rdmaConfig: Optional[RdmaConfig] = None
   dataInTransitEncryptionConfig: Optional[DataInTransitEncryptionConfig] = None
   vsanHealthConfig: Optional[VsanHealthConfigSpec] = None
   mode: Optional[str] = None
   vsanPMemConfig: Optional[VsanPMemConfig] = None
   vsanEsaConfigInfo: Optional[VsanEsaConfigInfo] = None
   xvcDatastoreConfig: Optional[XVCDatastoreConfig] = None
   serverClusterConfig: Optional[VcRemoteVsanServerClusterConfig] = None
   datastoreDefaultPolicySelectionConfig: Optional[VsanDatastoreDefaultPolicySelectionConfig] = None
   snapServiceConfig: Optional[SnapServiceConfig] = None
   deconvergedNetConfig: Optional[VsanDeconvergedNetConfig] = None
   siteFaultDomainConfig: Optional[SiteFaultDomainConfig] = None



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import ClassVar
from typing import Optional

from pyVmomi.VmomiSupport import Enum

from pyVmomi.vmodl import DynamicData

class SpaceLoadBalanceConfig(DynamicData):
   class SpaceThresholdMode(Enum):
      utilization: ClassVar['SpaceThresholdMode'] = 'utilization'
      freeSpace: ClassVar['SpaceThresholdMode'] = 'freeSpace'

   spaceThresholdMode: Optional[str] = None
   spaceUtilizationThreshold: Optional[int] = None
   freeSpaceThresholdGB: Optional[int] = None
   minSpaceUtilizationDifference: Optional[int] = None



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import Optional

from pyVmomi.vmodl import DynamicData
from pyVmomi.vmodl import KeyAnyValue

class ExtendedElementDescription(DynamicData):
   label: str
   summary: str
   key: str
   messageCatalogKeyPrefix: str
   messageArg: list[KeyAnyValue] = []



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import Optional

from pyVmomi.VmomiSupport import ManagedObject

from pyVmomi.vim import ManagedEntity

from pyVmomi.vim.view import ContainerView
from pyVmomi.vim.view import InventoryView
from pyVmomi.vim.view import ListView
from pyVmomi.vim.view import View

class ViewManager(ManagedObject):
   @property
   def viewList(self) -> list[View]: ...

   def CreateInventoryView(self) -> InventoryView: ...
   def CreateContainerView(self, container: ManagedEntity, type: list[type], recursive: bool) -> ContainerView: ...
   def CreateListView(self, obj: list[ManagedObject]) -> ListView: ...
   def CreateListViewFromView(self, view: View) -> ListView: ...



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import ClassVar
from typing import Optional

from pyVmomi.VmomiSupport import Enum

from pyVmomi.vmodl import DynamicData

class VmComponentProtectionSettings(DynamicData):
   class StorageVmReaction(Enum):
      disabled: ClassVar['StorageVmReaction'] = 'disabled'
      warning: ClassVar['StorageVmReaction'] = 'warning'
      restartConservative: ClassVar['StorageVmReaction'] = 'restartConservative'
      restartAggressive: ClassVar['StorageVmReaction'] = 'restartAggressive'
      clusterDefault: ClassVar['StorageVmReaction'] = 'clusterDefault'

   class VmReactionOnAPDCleared(Enum):
      none: ClassVar['VmReactionOnAPDCleared'] = 'none'
      reset: ClassVar['VmReactionOnAPDCleared'] = 'reset'
      useClusterDefault: ClassVar['VmReactionOnAPDCleared'] = 'useClusterDefault'

   vmStorageProtectionForAPD: Optional[str] = None
   enableAPDTimeoutForHosts: Optional[bool] = None
   vmTerminateDelayForAPDSec: Optional[int] = None
   vmReactionOnAPDCleared: Optional[str] = None
   vmStorageProtectionForPDL: Optional[str] = None



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import Optional

from pyVmomi.vim.cluster import VsanClusterHealthResultBase
from pyVmomi.vim.cluster import VsanClusterHealthResultColumnInfo
from pyVmomi.vim.cluster import VsanClusterHealthResultRow

class VsanClusterHealthResultTable(VsanClusterHealthResultBase):
   columns: list[VsanClusterHealthResultColumnInfo] = []
   rows: list[VsanClusterHealthResultRow] = []



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from datetime import datetime

from typing import ClassVar
from typing import Optional

from pyVmomi.VmomiSupport import Enum
from pyVmomi.VmomiSupport import ManagedObject

from pyVmomi.vim import ClusterComputeResource
from pyVmomi.vim import HostSystem
from pyVmomi.vim import Task

from pyVmomi.vmodl import DynamicData

from pyVmomi.vim.vsan.host import DiskMapping

class VsanUpgradeSystem(ManagedObject):
   class PreflightCheckIssue(DynamicData):
      msg: str

   class HostsDisconnectedIssue(PreflightCheckIssue):
      hosts: list[HostSystem] = []

   class MissingHostsInClusterIssue(PreflightCheckIssue):
      hosts: list[HostSystem] = []

   class RogueHostsInClusterIssue(PreflightCheckIssue):
      uuids: list[str] = []

   class WrongEsxVersionIssue(PreflightCheckIssue):
      hosts: list[HostSystem] = []

   class AutoClaimEnabledOnHostsIssue(PreflightCheckIssue):
      hosts: list[HostSystem] = []

   class APIBrokenIssue(PreflightCheckIssue):
      hosts: list[HostSystem] = []

   class V2ObjectsPresentDuringDowngradeIssue(PreflightCheckIssue):
      uuids: list[str] = []

   class NotEnoughFreeCapacityIssue(PreflightCheckIssue):
      reducedRedundancyUpgradePossible: bool

   class NetworkPartitionInfo(DynamicData):
      hosts: list[HostSystem] = []

   class NetworkPartitionIssue(PreflightCheckIssue):
      partitions: list[NetworkPartitionInfo] = []

   class PreflightCheckResult(DynamicData):
      issues: list[PreflightCheckIssue] = []
      diskMappingToRestore: Optional[DiskMapping] = None

   class UpgradeHistoryItem(DynamicData):
      timestamp: datetime
      host: Optional[HostSystem] = None
      message: str
      task: Optional[Task] = None

   class UpgradeHistoryDiskGroupOpType(Enum):
      add: ClassVar['UpgradeHistoryDiskGroupOpType'] = 'add'
      remove: ClassVar['UpgradeHistoryDiskGroupOpType'] = 'remove'

   class UpgradeHistoryDiskGroupOp(UpgradeHistoryItem):
      operation: str
      diskMapping: DiskMapping

   class UpgradeHistoryPreflightFail(UpgradeHistoryItem):
      preflightResult: PreflightCheckResult

   class UpgradeStatus(DynamicData):
      inProgress: bool
      history: list[UpgradeHistoryItem] = []
      aborted: Optional[bool] = None
      completed: Optional[bool] = None
      progress: Optional[int] = None

   def PerformUpgradePreflightCheck(self, cluster: ClusterComputeResource, downgradeFormat: Optional[bool]) -> PreflightCheckResult: ...
   def QueryUpgradeStatus(self, cluster: ClusterComputeResource) -> UpgradeStatus: ...
   def PerformUpgrade(self, cluster: ClusterComputeResource, performObjectUpgrade: Optional[bool], downgradeFormat: Optional[bool], allowReducedRedundancy: Optional[bool], excludeHosts: list[HostSystem]) -> Task: ...



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import ClassVar
from typing import Optional

from pyVmomi.VmomiSupport import Enum

from pyVmomi.vmodl import DynamicData

from pyVmomi.vim.option import OptionValue

class DpmConfigInfo(DynamicData):
   class DpmBehavior(Enum):
      manual: ClassVar['DpmBehavior'] = 'manual'
      automated: ClassVar['DpmBehavior'] = 'automated'

   enabled: Optional[bool] = None
   defaultDpmBehavior: Optional[DpmBehavior] = None
   hostPowerActionRate: Optional[int] = None
   option: list[OptionValue] = []



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import ClassVar
from typing import Optional

from pyVmomi.VmomiSupport import Enum

from pyVmomi.vmodl import DynamicData

from pyVmomi.vim.cluster import VsanPerfMetricId
from pyVmomi.vim.cluster import VsanPerfThreshold

class VsanPerfGraph(DynamicData):
   class VsanPerfStatsUnitType(Enum):
      number: ClassVar['VsanPerfStatsUnitType'] = 'number'
      time_ms: ClassVar['VsanPerfStatsUnitType'] = 'time_ms'
      percentage: ClassVar['VsanPerfStatsUnitType'] = 'percentage'
      size_bytes: ClassVar['VsanPerfStatsUnitType'] = 'size_bytes'
      rate_bytes: ClassVar['VsanPerfStatsUnitType'] = 'rate_bytes'
      permille: ClassVar['VsanPerfStatsUnitType'] = 'permille'
      time_s: ClassVar['VsanPerfStatsUnitType'] = 'time_s'
      time_us: ClassVar['VsanPerfStatsUnitType'] = 'time_us'
      time_ns: ClassVar['VsanPerfStatsUnitType'] = 'time_ns'
      VsanPerfStatsUnitType_Unknown: ClassVar['VsanPerfStatsUnitType'] = 'VsanPerfStatsUnitType_Unknown'

   id: str
   metrics: list[VsanPerfMetricId] = []
   unit: str
   threshold: Optional[VsanPerfThreshold] = None
   name: Optional[str] = None
   description: Optional[str] = None
   secondGraph: Optional[VsanPerfGraph] = None



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from datetime import datetime

from typing import Optional

from pyVmomi.vmodl import DynamicData
from pyVmomi.vmodl import MethodFault

from pyVmomi.vim.host import VsanKmsHealth

class VsanVcKmipServersHealth(DynamicData):
   health: Optional[str] = None
   error: Optional[MethodFault] = None
   kmsProviderId: Optional[str] = None
   kmsHealth: list[VsanKmsHealth] = []
   clientCertHealth: Optional[str] = None
   clientCertExpireDate: Optional[datetime] = None
   isAwsKms: Optional[bool] = None
   cmkHealth: Optional[str] = None
   kekExpireHealth: Optional[str] = None
   kekExpireDate: Optional[datetime] = None
   hostKeyExpireHealth: Optional[str] = None
   hostKeyExpireDate: Optional[datetime] = None



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import NoReturn
from typing import Optional

from pyVmomi.VmomiSupport import ManagedObject

from pyVmomi.vim.host import DiagnosticPartition
from pyVmomi.vim.host import ScsiDisk

class DiagnosticSystem(ManagedObject):
   @property
   def activePartition(self) -> Optional[DiagnosticPartition]: ...

   def QueryAvailablePartition(self) -> list[DiagnosticPartition]: ...
   def SelectActivePartition(self, partition: Optional[ScsiDisk.Partition]) -> NoReturn: ...
   def QueryPartitionCreateOptions(self, storageType: str, diagnosticType: str) -> list[DiagnosticPartition.CreateOption]: ...
   def QueryPartitionCreateDesc(self, diskUuid: str, diagnosticType: str) -> DiagnosticPartition.CreateDescription: ...
   def CreateDiagnosticPartition(self, spec: DiagnosticPartition.CreateSpec) -> NoReturn: ...



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import Optional

from pyVmomi.vmodl import DynamicData

from pyVmomi.vim.host import HostBusAdapter
from pyVmomi.vim.host import ScsiLun
from pyVmomi.vim.host import TargetTransport

class PlugStoreTopology(DynamicData):
   class Adapter(DynamicData):
      key: str
      adapter: HostBusAdapter
      path: list[Path] = []

   class Path(DynamicData):
      key: str
      name: str
      channelNumber: Optional[int] = None
      targetNumber: Optional[int] = None
      lunNumber: Optional[int] = None
      adapter: Optional[Adapter] = None
      target: Optional[Target] = None
      device: Optional[Device] = None

   class Device(DynamicData):
      key: str
      lun: ScsiLun
      path: list[Path] = []

   class Plugin(DynamicData):
      key: str
      name: str
      device: list[Device] = []
      claimedPath: list[Path] = []

   class Target(DynamicData):
      key: str
      transport: Optional[TargetTransport] = None

   adapter: list[Adapter] = []
   path: list[Path] = []
   target: list[Target] = []
   device: list[Device] = []
   plugin: list[Plugin] = []



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import ClassVar
from typing import Optional

from pyVmomi.VmomiSupport import Enum

from pyVmomi.vmodl import DynamicData

class Ruleset(DynamicData):
   class IpNetwork(DynamicData):
      network: str
      prefixLength: int

   class IpList(DynamicData):
      ipAddress: list[str] = []
      ipNetwork: list[IpNetwork] = []
      allIp: bool

   class RulesetSpec(DynamicData):
      allowedHosts: IpList

   class Rule(DynamicData):
      class Direction(Enum):
         inbound: ClassVar['Direction'] = 'inbound'
         outbound: ClassVar['Direction'] = 'outbound'

      class PortType(Enum):
         src: ClassVar['PortType'] = 'src'
         dst: ClassVar['PortType'] = 'dst'

      class Protocol(Enum):
         tcp: ClassVar['Protocol'] = 'tcp'
         udp: ClassVar['Protocol'] = 'udp'

      port: int
      endPort: Optional[int] = None
      direction: Direction
      portType: Optional[PortType] = None
      protocol: str

   key: str
   label: str
   required: bool
   rule: list[Rule] = []
   service: Optional[str] = None
   enabled: bool
   allowedHosts: Optional[IpList] = None
   userControllable: Optional[bool] = None
   ipListUserConfigurable: Optional[bool] = None



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import ClassVar
from typing import Optional

from pyVmomi.VmomiSupport import Enum

from pyVmomi.vmodl import DynamicData

class LicenseFilePrintData(DynamicData):
   class AutoMode(Enum):
      perServer: ClassVar['AutoMode'] = 'perServer'
      perSeat: ClassVar['AutoMode'] = 'perSeat'

   autoMode: AutoMode
   autoUsers: Optional[int] = None



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import Optional

from pyVmomi.vim.fault import OvfExport

from pyVmomi.vim.vm.device import VirtualDevice

class OvfHardwareExport(OvfExport):
   device: Optional[VirtualDevice] = None
   vmPath: str



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import ClassVar
from typing import Optional

from pyVmomi.VmomiSupport import Enum
from pyVmomi.VmomiSupport import ManagedObject

from pyVmomi.vim import ClusterComputeResource
from pyVmomi.vim import ComputeResource
from pyVmomi.vim import HostSystem
from pyVmomi.vim import Task

from pyVmomi.vmodl import DynamicData
from pyVmomi.vmodl import MethodFault

from pyVmomi.vim.vm.device import VirtualDiskId

class IoFilterManager(ManagedObject):
   class IoFilterInfo(DynamicData):
      id: str
      name: str
      vendor: str
      version: str
      type: Optional[str] = None
      summary: Optional[str] = None
      releaseDate: Optional[str] = None

   class HostIoFilterInfo(IoFilterInfo):
      available: bool

   class OperationType(Enum):
      install: ClassVar['OperationType'] = 'install'
      uninstall: ClassVar['OperationType'] = 'uninstall'
      upgrade: ClassVar['OperationType'] = 'upgrade'

   class ClusterIoFilterInfo(IoFilterInfo):
      opType: str
      vibUrl: Optional[str] = None

   class IoFilterType(Enum):
      cache: ClassVar['IoFilterType'] = 'cache'
      replication: ClassVar['IoFilterType'] = 'replication'
      encryption: ClassVar['IoFilterType'] = 'encryption'
      compression: ClassVar['IoFilterType'] = 'compression'
      inspection: ClassVar['IoFilterType'] = 'inspection'
      datastoreIoControl: ClassVar['IoFilterType'] = 'datastoreIoControl'
      dataProvider: ClassVar['IoFilterType'] = 'dataProvider'
      dataCapture: ClassVar['IoFilterType'] = 'dataCapture'

   class SslTrust(DynamicData):
      pass

   class PinnedCertificate(SslTrust):
      sslCertificate: str

   class UntrustedCertificate(SslTrust):
      pass

   class QueryIssueResult(DynamicData):
      class HostIssue(DynamicData):
         host: HostSystem
         issue: list[MethodFault] = []

      opType: str
      hostIssue: list[HostIssue] = []

   def InstallIoFilter(self, vibUrl: str, compRes: ComputeResource, vibSslTrust: Optional[SslTrust]) -> Task: ...
   def UninstallIoFilter(self, filterId: str, compRes: ComputeResource) -> Task: ...
   def UpgradeIoFilter(self, filterId: str, compRes: ComputeResource, vibUrl: str, vibSslTrust: Optional[SslTrust]) -> Task: ...
   def QueryIssue(self, filterId: str, compRes: ComputeResource) -> QueryIssueResult: ...
   def QueryIoFilterInfo(self, compRes: ComputeResource) -> list[ClusterIoFilterInfo]: ...
   def ResolveInstallationErrorsOnHost(self, filterId: str, host: HostSystem) -> Task: ...
   def ResolveInstallationErrorsOnCluster(self, filterId: str, cluster: ClusterComputeResource) -> Task: ...
   def QueryDisksUsingFilter(self, filterId: str, compRes: ComputeResource) -> list[VirtualDiskId]: ...
   def InitiateTransitionToVLCM(self, cluster: ClusterComputeResource) -> Task: ...



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import ClassVar
from typing import Optional

from pyVmomi.VmomiSupport import Enum

from pyVmomi.vim import HostSystem

from pyVmomi.vim.fault import VimFault

class CannotEnableVmcpForCluster(VimFault):
   class Reason(Enum):
      APDTimeoutDisabled: ClassVar['Reason'] = 'APDTimeoutDisabled'

   host: Optional[HostSystem] = None
   hostName: Optional[str] = None
   reason: Optional[str] = None



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import Optional

from pyVmomi.VmomiSupport import long

from pyVmomi.vmodl import DynamicData

from pyVmomi.vim.host import VsanVmdkLoadTestSpec

class VsanStorageWorkloadType(DynamicData):
   specs: list[VsanVmdkLoadTestSpec] = []
   typeId: str
   name: str
   description: str
   duration: Optional[long] = None



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import Optional

from pyVmomi.vim import HostSystem
from pyVmomi.vim import VirtualMachine

from pyVmomi.vmodl import DynamicData

from pyVmomi.vim.cluster import DasAdvancedRuntimeInfo

class DasFailoverLevelAdvancedRuntimeInfo(DasAdvancedRuntimeInfo):
   class SlotInfo(DynamicData):
      numVcpus: int
      cpuMHz: int
      memoryMB: int

   class HostSlots(DynamicData):
      host: HostSystem
      slots: int

   class VmSlots(DynamicData):
      vm: VirtualMachine
      slots: int

   slotInfo: SlotInfo
   totalSlots: int
   usedSlots: int
   unreservedSlots: int
   totalVms: int
   totalHosts: int
   totalGoodHosts: int
   hostSlots: list[HostSlots] = []
   vmsRequiringMultipleSlots: list[VmSlots] = []



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import Optional

from pyVmomi.VmomiSupport import ManagedObject

from pyVmomi.vim import ClusterComputeResource
from pyVmomi.vim import Network
from pyVmomi.vim import Task

from pyVmomi.vim.vsan import FileServiceDomain
from pyVmomi.vim.vsan import FileServiceDomainConfig
from pyVmomi.vim.vsan import FileServiceDomainQuerySpec
from pyVmomi.vim.vsan import FileShareConfig
from pyVmomi.vim.vsan import FileShareQueryResult
from pyVmomi.vim.vsan import FileShareQuerySpec
from pyVmomi.vim.vsan import FileShareSnapshotConfig
from pyVmomi.vim.vsan import FileShareSnapshotQueryResult
from pyVmomi.vim.vsan import FileShareSnapshotQuerySpec
from pyVmomi.vim.vsan import VsanFileServiceOvfSpec
from pyVmomi.vim.vsan import VsanFileServicePreflightCheckResult

class VsanFileServiceSystem(ManagedObject):
   def DownloadFileServiceOvf(self, downloadUrl: str) -> Task: ...
   def QueryFileServiceOvfs(self) -> list[VsanFileServiceOvfSpec]: ...
   def FindOvfDownloadUrl(self, cluster: ClusterComputeResource) -> str: ...
   def PerformFileServicePreflightCheck(self, cluster: ClusterComputeResource, domainConfig: Optional[FileServiceDomainConfig], network: Optional[Network], scope: Optional[str], domainUuid: Optional[str]) -> VsanFileServicePreflightCheckResult: ...
   def CreateFileServiceDomain(self, domainConfig: FileServiceDomainConfig, cluster: Optional[ClusterComputeResource]) -> Task: ...
   def ReconfigureFileServiceDomain(self, domainUuid: str, domainConfig: FileServiceDomainConfig, cluster: Optional[ClusterComputeResource], deleteDomainConfigFields: list[str]) -> Task: ...
   def RemoveFileServiceDomain(self, domainUuid: str, cluster: Optional[ClusterComputeResource]) -> Task: ...
   def QueryFileServiceDomains(self, querySpec: Optional[FileServiceDomainQuerySpec], cluster: Optional[ClusterComputeResource]) -> list[FileServiceDomain]: ...
   def CreateFileShare(self, config: FileShareConfig, cluster: Optional[ClusterComputeResource]) -> Task: ...
   def ReconfigureFileShare(self, shareUuid: str, config: FileShareConfig, cluster: Optional[ClusterComputeResource], deleteLabelKeys: list[str], force: Optional[bool]) -> Task: ...
   def RemoveFileShare(self, shareUuid: str, cluster: Optional[ClusterComputeResource], force: Optional[bool]) -> Task: ...
   def QueryFileShares(self, querySpec: FileShareQuerySpec, cluster: Optional[ClusterComputeResource]) -> Optional[FileShareQueryResult]: ...
   def UpgradeFsvm(self, cluster: ClusterComputeResource) -> Task: ...
   def RebalanceFileService(self, cluster: Optional[ClusterComputeResource]) -> Task: ...
   def CreateFileShareSnapshot(self, config: FileShareSnapshotConfig, cluster: Optional[ClusterComputeResource]) -> Task: ...
   def RemoveFileShareSnapshot(self, shareUuid: str, snapshotName: str, cluster: Optional[ClusterComputeResource]) -> Task: ...
   def QueryFileShareSnapshots(self, querySpec: FileShareSnapshotQuerySpec, cluster: Optional[ClusterComputeResource]) -> Optional[FileShareSnapshotQueryResult]: ...



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import NoReturn
from typing import Optional

from pyVmomi.VmomiSupport import ManagedObject

from pyVmomi.vslm import QueryDatastoreInfoResult

from pyVmomi.vim.vslm import ID

class StorageLifecycleManager(ManagedObject):
   def SyncDatastore(self, datastoreUrl: str, fullSync: bool, fcdId: Optional[ID]) -> NoReturn: ...
   def QueryDatastoreInfo(self, datastoreUrl: str) -> list[QueryDatastoreInfoResult]: ...



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import ClassVar
from typing import Optional

from pyVmomi.VmomiSupport import Enum
from pyVmomi.VmomiSupport import PropertyPath

from pyVmomi.vmodl import DynamicData

from pyVmomi.vim.option import BoolOption
from pyVmomi.vim.option import ChoiceOption

class VirtualDeviceOption(DynamicData):
   class BackingOption(DynamicData):
      type: type

   class FileBackingOption(BackingOption):
      class FileExtension(Enum):
         iso: ClassVar['FileExtension'] = 'iso'
         flp: ClassVar['FileExtension'] = 'flp'
         vmdk: ClassVar['FileExtension'] = 'vmdk'
         dsk: ClassVar['FileExtension'] = 'dsk'
         rdm: ClassVar['FileExtension'] = 'rdm'

      fileNameExtensions: Optional[ChoiceOption] = None

   class DeviceBackingOption(BackingOption):
      autoDetectAvailable: BoolOption

   class RemoteDeviceBackingOption(BackingOption):
      autoDetectAvailable: BoolOption

   class PipeBackingOption(BackingOption):
      pass

   class URIBackingOption(BackingOption):
      class Direction(Enum):
         server: ClassVar['Direction'] = 'server'
         client: ClassVar['Direction'] = 'client'

      directions: ChoiceOption

   class ConnectOption(DynamicData):
      startConnected: BoolOption
      allowGuestControl: BoolOption

   class BusSlotOption(DynamicData):
      type: type

   type: type
   connectOption: Optional[ConnectOption] = None
   busSlotOption: Optional[BusSlotOption] = None
   controllerType: Optional[type] = None
   autoAssignController: Optional[BoolOption] = None
   backingOption: list[BackingOption] = []
   defaultBackingOptionIndex: Optional[int] = None
   licensingLimit: list[PropertyPath] = []
   deprecated: bool
   plugAndPlay: bool
   hotRemoveSupported: bool
   numaSupported: Optional[bool] = None



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import Optional

from pyVmomi.vim import LicenseManager
from pyVmomi.vim import UserDirectory

from pyVmomi.vmodl import DynamicData

from pyVmomi.vim.encryption import CryptoManager

from pyVmomi.vim.host import AssignableHardwareManager
from pyVmomi.vim.host import AuthenticationManager
from pyVmomi.vim.host import AutoStartManager
from pyVmomi.vim.host import BootDeviceSystem
from pyVmomi.vim.host import CacheConfigurationManager
from pyVmomi.vim.host import CertificateManager
from pyVmomi.vim.host import CpuSchedulerSystem
from pyVmomi.vim.host import DatastoreSystem
from pyVmomi.vim.host import DateTimeSystem
from pyVmomi.vim.host import DiagnosticSystem
from pyVmomi.vim.host import EsxAgentHostManager
from pyVmomi.vim.host import FirewallSystem
from pyVmomi.vim.host import FirmwareSystem
from pyVmomi.vim.host import GraphicsManager
from pyVmomi.vim.host import HealthStatusSystem
from pyVmomi.vim.host import HostAccessManager
from pyVmomi.vim.host import ImageConfigManager
from pyVmomi.vim.host import IscsiManager
from pyVmomi.vim.host import KernelModuleSystem
from pyVmomi.vim.host import LocalAccountManager
from pyVmomi.vim.host import MemoryManagerSystem
from pyVmomi.vim.host import MessageBusProxy
from pyVmomi.vim.host import NetworkSystem
from pyVmomi.vim.host import NvdimmSystem
from pyVmomi.vim.host import PatchManager
from pyVmomi.vim.host import PciPassthruSystem
from pyVmomi.vim.host import PowerSystem
from pyVmomi.vim.host import ServiceSystem
from pyVmomi.vim.host import SnmpSystem
from pyVmomi.vim.host import StorageSystem
from pyVmomi.vim.host import VFlashManager
from pyVmomi.vim.host import VMotionSystem
from pyVmomi.vim.host import VirtualNicManager
from pyVmomi.vim.host import VsanInternalSystem
from pyVmomi.vim.host import VsanSystem

from pyVmomi.vim.option import OptionManager

class ConfigManager(DynamicData):
   cpuScheduler: Optional[CpuSchedulerSystem] = None
   datastoreSystem: Optional[DatastoreSystem] = None
   memoryManager: Optional[MemoryManagerSystem] = None
   storageSystem: Optional[StorageSystem] = None
   networkSystem: Optional[NetworkSystem] = None
   vmotionSystem: Optional[VMotionSystem] = None
   virtualNicManager: Optional[VirtualNicManager] = None
   serviceSystem: Optional[ServiceSystem] = None
   firewallSystem: Optional[FirewallSystem] = None
   advancedOption: Optional[OptionManager] = None
   diagnosticSystem: Optional[DiagnosticSystem] = None
   autoStartManager: Optional[AutoStartManager] = None
   snmpSystem: Optional[SnmpSystem] = None
   dateTimeSystem: Optional[DateTimeSystem] = None
   patchManager: Optional[PatchManager] = None
   imageConfigManager: Optional[ImageConfigManager] = None
   bootDeviceSystem: Optional[BootDeviceSystem] = None
   firmwareSystem: Optional[FirmwareSystem] = None
   healthStatusSystem: Optional[HealthStatusSystem] = None
   pciPassthruSystem: Optional[PciPassthruSystem] = None
   licenseManager: Optional[LicenseManager] = None
   kernelModuleSystem: Optional[KernelModuleSystem] = None
   authenticationManager: Optional[AuthenticationManager] = None
   powerSystem: Optional[PowerSystem] = None
   cacheConfigurationManager: Optional[CacheConfigurationManager] = None
   esxAgentHostManager: Optional[EsxAgentHostManager] = None
   iscsiManager: Optional[IscsiManager] = None
   vFlashManager: Optional[VFlashManager] = None
   vsanSystem: Optional[VsanSystem] = None
   messageBusProxy: Optional[MessageBusProxy] = None
   userDirectory: Optional[UserDirectory] = None
   accountManager: Optional[LocalAccountManager] = None
   hostAccessManager: Optional[HostAccessManager] = None
   graphicsManager: Optional[GraphicsManager] = None
   vsanInternalSystem: Optional[VsanInternalSystem] = None
   certificateManager: Optional[CertificateManager] = None
   cryptoManager: Optional[CryptoManager] = None
   nvdimmSystem: Optional[NvdimmSystem] = None
   assignableHardwareManager: Optional[AssignableHardwareManager] = None



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import ClassVar
from typing import Optional

from pyVmomi.VmomiSupport import Enum

from pyVmomi.vmodl import DynamicData
from pyVmomi.vmodl import MethodFault

class ScheduledHardwareUpgradeInfo(DynamicData):
   class HardwareUpgradePolicy(Enum):
      never: ClassVar['HardwareUpgradePolicy'] = 'never'
      onSoftPowerOff: ClassVar['HardwareUpgradePolicy'] = 'onSoftPowerOff'
      always: ClassVar['HardwareUpgradePolicy'] = 'always'

   class HardwareUpgradeStatus(Enum):
      none: ClassVar['HardwareUpgradeStatus'] = 'none'
      pending: ClassVar['HardwareUpgradeStatus'] = 'pending'
      success: ClassVar['HardwareUpgradeStatus'] = 'success'
      failed: ClassVar['HardwareUpgradeStatus'] = 'failed'

   upgradePolicy: Optional[str] = None
   versionKey: Optional[str] = None
   scheduledHardwareUpgradeStatus: Optional[str] = None
   fault: Optional[MethodFault] = None



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from datetime import datetime

from typing import Optional

from pyVmomi.VmomiSupport import long

from pyVmomi.vim import HostSystem
from pyVmomi.vim import VirtualMachine

from pyVmomi.vmodl import DynamicData

class DrsMigration(DynamicData):
   key: str
   time: datetime
   vm: VirtualMachine
   cpuLoad: Optional[int] = None
   memoryLoad: Optional[long] = None
   source: HostSystem
   sourceCpuLoad: Optional[int] = None
   sourceMemoryLoad: Optional[long] = None
   destination: HostSystem
   destinationCpuLoad: Optional[int] = None
   destinationMemoryLoad: Optional[long] = None



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import NoReturn
from typing import Optional

from pyVmomi.VmomiSupport import ManagedObject
from pyVmomi.VmomiSupport import long

from pyVmomi.vim import Datacenter
from pyVmomi.vim import Datastore

from pyVmomi.vmodl import DynamicData

class DatastoreNamespaceManager(ManagedObject):
   class DirectoryInfo(DynamicData):
      capacity: long
      used: long

   def CreateDirectory(self, datastore: Datastore, displayName: Optional[str], policy: Optional[str], size: Optional[long]) -> str: ...
   def DeleteDirectory(self, datacenter: Optional[Datacenter], datastorePath: str) -> NoReturn: ...
   def ConvertNamespacePathToUuidPath(self, datacenter: Optional[Datacenter], namespaceUrl: str) -> str: ...
   def IncreaseDirectorySize(self, datacenter: Optional[Datacenter], stableName: str, size: long) -> NoReturn: ...
   def QueryDirectoryInfo(self, datacenter: Optional[Datacenter], stableName: str) -> DirectoryInfo: ...



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import Optional

from pyVmomi.vim import ImportSpec
from pyVmomi.vim import ResourcePool

from pyVmomi.vim.vm import ConfigSpec

class VmImportSpec(ImportSpec):
   configSpec: ConfigSpec
   resPoolEntity: Optional[ResourcePool] = None



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import ClassVar
from typing import Optional

from pyVmomi.VmomiSupport import Enum

from pyVmomi.vmodl import DynamicData

class IPAssignmentInfo(DynamicData):
   class IpAllocationPolicy(Enum):
      dhcpPolicy: ClassVar['IpAllocationPolicy'] = 'dhcpPolicy'
      transientPolicy: ClassVar['IpAllocationPolicy'] = 'transientPolicy'
      fixedPolicy: ClassVar['IpAllocationPolicy'] = 'fixedPolicy'
      fixedAllocatedPolicy: ClassVar['IpAllocationPolicy'] = 'fixedAllocatedPolicy'

   class AllocationSchemes(Enum):
      dhcp: ClassVar['AllocationSchemes'] = 'dhcp'
      ovfenv: ClassVar['AllocationSchemes'] = 'ovfenv'

   class Protocols(Enum):
      IPv4: ClassVar['Protocols'] = 'IPv4'
      IPv6: ClassVar['Protocols'] = 'IPv6'

   supportedAllocationScheme: list[str] = []
   ipAllocationPolicy: Optional[str] = None
   supportedIpProtocol: list[str] = []
   ipProtocol: Optional[str] = None



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from datetime import datetime

from typing import Optional

from pyVmomi.vmodl import DynamicData

class CustomizationSpecInfo(DynamicData):
   name: str
   description: str
   type: str
   changeVersion: Optional[str] = None
   lastUpdateTime: Optional[datetime] = None



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import ClassVar
from typing import Optional

from pyVmomi.VmomiSupport import Enum

from pyVmomi.vmodl import DynamicData

class VirtualDeviceSwap(DynamicData):
   class DeviceSwapStatus(Enum):
      none: ClassVar['DeviceSwapStatus'] = 'none'
      scheduled: ClassVar['DeviceSwapStatus'] = 'scheduled'
      inprogress: ClassVar['DeviceSwapStatus'] = 'inprogress'
      failed: ClassVar['DeviceSwapStatus'] = 'failed'
      completed: ClassVar['DeviceSwapStatus'] = 'completed'

   class DeviceSwapInfo(DynamicData):
      enabled: Optional[bool] = None
      applicable: Optional[bool] = None
      status: Optional[str] = None

   lsiToPvscsi: Optional[DeviceSwapInfo] = None



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from datetime import datetime

from typing import ClassVar
from typing import Optional

from pyVmomi.VmomiSupport import Enum

from pyVmomi.vim import ManagedEntity
from pyVmomi.vim import ResourceAllocationInfo

from pyVmomi.vmodl import DynamicData

class ResourceConfigSpec(DynamicData):
   class ScaleSharesBehavior(Enum):
      disabled: ClassVar['ScaleSharesBehavior'] = 'disabled'
      scaleCpuAndMemoryShares: ClassVar['ScaleSharesBehavior'] = 'scaleCpuAndMemoryShares'

   entity: Optional[ManagedEntity] = None
   changeVersion: Optional[str] = None
   lastModified: Optional[datetime] = None
   cpuAllocation: ResourceAllocationInfo
   memoryAllocation: ResourceAllocationInfo
   scaleDescendantsShares: Optional[str] = None



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from datetime import datetime

from typing import Optional

from pyVmomi.vmodl import DynamicData

from pyVmomi.vim.cluster import VsanClusterHealthResultBase
from pyVmomi.vim.cluster import VsanHealthCorrelation

class VsanHistoricalHealthTest(DynamicData):
   timestamp: datetime
   health: str
   testDetails: list[VsanClusterHealthResultBase] = []
   testCorrelation: Optional[VsanHealthCorrelation] = None



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import Optional

from pyVmomi.vim.vsan import MountPrecheckItem
from pyVmomi.vim.vsan import MountPrecheckNetworkConnectivityDetail

class MountPrecheckNetworkConnectivityResult(MountPrecheckItem):
   details: list[MountPrecheckNetworkConnectivityDetail] = []



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import ClassVar
from typing import Optional

from pyVmomi.VmomiSupport import Enum
from pyVmomi.VmomiSupport import long
from pyVmomi.VmomiSupport import short

from pyVmomi.vim import Datastore
from pyVmomi.vim import DesiredSoftwareSpec
from pyVmomi.vim import EnvironmentBrowser
from pyVmomi.vim import HostSystem
from pyVmomi.vim import ManagedEntity
from pyVmomi.vim import Network
from pyVmomi.vim import ResourcePool
from pyVmomi.vim import Task

from pyVmomi.vmodl import DynamicData

from pyVmomi.vim.host import ConnectSpec

class ComputeResource(ManagedEntity):
   class Summary(DynamicData):
      totalCpu: int
      totalMemory: long
      numCpuCores: short
      numCpuThreads: short
      effectiveCpu: int
      effectiveMemory: long
      numHosts: int
      numEffectiveHosts: int
      overallStatus: ManagedEntity.Status

   class NetworkBootMode(Enum):
      bootstrap: ClassVar['NetworkBootMode'] = 'bootstrap'
      stateless: ClassVar['NetworkBootMode'] = 'stateless'

   class ConfigInfo(DynamicData):
      vmSwapPlacement: str
      spbmEnabled: Optional[bool] = None
      defaultHardwareVersionKey: Optional[str] = None
      maximumHardwareVersionKey: Optional[str] = None

   class HostSPBMLicenseInfo(DynamicData):
      class HostSPBMLicenseState(Enum):
         licensed: ClassVar['HostSPBMLicenseState'] = 'licensed'
         unlicensed: ClassVar['HostSPBMLicenseState'] = 'unlicensed'
         unknown: ClassVar['HostSPBMLicenseState'] = 'unknown'

      host: HostSystem
      licenseState: HostSPBMLicenseState

   class HostSeedSpec(DynamicData):
      class SingleHostSpec(DynamicData):
         newHostCnxSpec: Optional[ConnectSpec] = None
         existingHost: Optional[HostSystem] = None

      singleHostSpec: SingleHostSpec

   class ConfigSpec(DynamicData):
      vmSwapPlacement: Optional[str] = None
      spbmEnabled: Optional[bool] = None
      defaultHardwareVersionKey: Optional[str] = None
      desiredSoftwareSpec: Optional[DesiredSoftwareSpec] = None
      maximumHardwareVersionKey: Optional[str] = None
      enableConfigManager: Optional[bool] = None
      hostSeedSpec: Optional[HostSeedSpec] = None
      softwareSpecId: Optional[str] = None
      networkBootMode: Optional[str] = None

   @property
   def resourcePool(self) -> Optional[ResourcePool]: ...
   @property
   def host(self) -> list[HostSystem]: ...
   @property
   def datastore(self) -> list[Datastore]: ...
   @property
   def network(self) -> list[Network]: ...
   @property
   def summary(self) -> Summary: ...
   @property
   def environmentBrowser(self) -> Optional[EnvironmentBrowser]: ...
   @property
   def configurationEx(self) -> ConfigInfo: ...
   @property
   def lifecycleManaged(self) -> Optional[bool]: ...
   @property
   def configManagerEnabled(self) -> Optional[bool]: ...
   @property
   def networkBootMode(self) -> Optional[str]: ...

   def EnableNetworkBoot(self, networkBootMode: str) -> Task: ...
   def DisableNetworkBoot(self) -> Task: ...
   def ReconfigureEx(self, spec: ConfigSpec, modify: bool) -> Task: ...



# Copyright (c) 2022-2025 Broadcom. All Rights Reserved.
# The term "Broadcom" refers to Broadcom Inc. and/or its subsidiaries.

import base64
import json

from datetime import datetime

from .five import PY3

from . import Iso8601
from .VmomiSupport import ManagedObject, DataObject, ManagedMethod, \
    UnknownManagedMethod, GetWsdlType, XMLNS_VMODL_BASE, binary


class VmomiJSONEncoder(json.JSONEncoder):
    """
        Custom JSON encoder to encode vSphere objects.
        When a ManagedObject is encoded, it gains three properties:
            _vimid is the _moId (ex: 'vm-42')
            _vimref is the moRef (ex: 'vim.VirtualMachine:vm-42')
            _vimtype is the class name (ex: 'vim.VirtualMachine')
        When a DataObject is encoded, it gains one property:
            _vimtype is the class name (ex: 'vim.VirtualMachineQuestionInfo')
        If the dynamicProperty and dynamicType are empty, they are optionally
            omitted from the results of DataObjects and ManagedObjects
        @example "Explode only the object passed in"
            data = json.dumps(vm, cls=VmomiJSONEncoder)
        @example "Explode specific objects"
            data = json.dumps(vm, cls=VmomiJSONEncoder,
                              explode=[vm, vm.network[0]])
        @example "Explode all virtual machines in a list and their snapshots"
            data = json.dumps([vm1, vm2], cls=VmomiJSONEncoder,
                              explode=[templateOf('VirtualMachine'),
                                       templateOf('VirtualMachineSnapshot')])
    """
    def __init__(self, *args, **kwargs):
        """
        Consumer must specify what types to explode into full content
        and what types to leave as a ManagedObjectReference.  If the
        root object of the encoding is a ManagedObject, it will be
        added to the explode list automatically.
        A ManagedObject is only exploded once, the first time it is
        encountered.  All subsequent times it will be a moRef.
        @param explode (list) A list of objects and/or types to
            expand in the conversion process.  Directly add any
            objects to the list, or add the type of any object
            using type(templateOf('VirtualMachine')) for example.
        @param strip_dynamic (bool) Every object normally contains
            a dynamicProperty list and a dynamicType field even if
            the contents are [] and None respectively.  These fields
            clutter the output making it more difficult for a person
            to read and bloat the size of the result unnecessarily.
            This option removes them if they are the empty values above.
            The default is False.
        """
        self._done = set()
        self._first = True
        self._explode = kwargs.pop('explode', None)
        self._strip_dynamic = kwargs.pop('strip_dynamic', False)
        super(VmomiJSONEncoder, self).__init__(*args, **kwargs)

    def _remove_empty_dynamic_if(self, result):
        if self._strip_dynamic:
            if 'dynamicProperty' in result and len(result['dynamicProperty']) == 0:
                result.pop('dynamicProperty')
            if 'dynamicType' in result and not result['dynamicType']:
                result.pop('dynamicType')
        return result

    def default(self, obj):  # pylint: disable=method-hidden
        if self._first:
            self._first = False
            if not self._explode:
                self._explode = []
            if isinstance(obj, ManagedObject):
                self._explode.append(obj)
        if isinstance(obj, ManagedObject):
            if self.explode(obj):
                result = {}
                result['_vimid'] = obj._moId
                result['_vimref'] = '{}:{}'.format(obj.__class__.__name__,
                                                   obj._moId)
                result['_vimtype'] = obj.__class__.__name__
                for prop in obj._GetPropertyList():
                    result[prop.name] = getattr(obj, prop.name)
                return self._remove_empty_dynamic_if(result)
            return str(obj).strip("'")  # see VmomiSupport.FormatObject
        if isinstance(obj, DataObject):
            result = {k:v for k,v in obj.__dict__.items()}
            result['_vimtype'] = obj.__class__.__name__
            return self._remove_empty_dynamic_if(result)
        if isinstance(obj, binary):
            result = base64.b64encode(obj)
            if PY3:  # see VmomiSupport.FormatObject
                result = str(result, 'utf-8')
            return result
        if isinstance(obj, datetime):
            return Iso8601.ISO8601Format(obj)
        if isinstance(obj, UnknownManagedMethod):
            return obj.name
        if isinstance(obj, ManagedMethod):
            return str(obj)  # see VmomiSupport.FormatObject
        if isinstance(obj, type):
            return obj.__name__
        super(VmomiJSONEncoder, self).default(obj)

    def explode(self, obj):
        """ Determine if the object should be exploded. """
        if obj in self._done:
            return False
        result = False
        for item in self._explode:
            if hasattr(item, '_moId'):
                # If it has a _moId it is an instance
                if obj._moId == item._moId:
                    result = True
            else:
                # If it does not have a _moId it is a template
                if obj.__class__.__name__ == item.__name__:
                    result = True
        if result:
            self._done.add(obj)
        return result


def templateOf(typestr):
    """ Returns a class template. """
    return GetWsdlType(XMLNS_VMODL_BASE, typestr)



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import ClassVar
from typing import Optional

from pyVmomi.VmomiSupport import Enum
from pyVmomi.VmomiSupport import PropertyPath

from pyVmomi.vim.alarm import AlarmExpression

class StateAlarmExpression(AlarmExpression):
   class StateOperator(Enum):
      isEqual: ClassVar['StateOperator'] = 'isEqual'
      isUnequal: ClassVar['StateOperator'] = 'isUnequal'

   operator: StateOperator
   type: type
   statePath: PropertyPath
   yellow: Optional[str] = None
   red: Optional[str] = None



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import Optional

from pyVmomi.VmomiSupport import ManagedObject

from pyVmomi.vim import ClusterComputeResource
from pyVmomi.vim import HostSystem
from pyVmomi.vim import Task

from pyVmomi.vim.host import MaintenanceSpec
from pyVmomi.vim.host import ScsiDisk

from pyVmomi.vim.vsan import DataEfficiencyCapacityState

from pyVmomi.vim.vsan.host import AddStoragePoolDiskSpec
from pyVmomi.vim.vsan.host import DeleteStoragePoolDiskSpec
from pyVmomi.vim.vsan.host import DiskMapInfoEx
from pyVmomi.vim.vsan.host import DiskMapping
from pyVmomi.vim.vsan.host import DiskMappingCreationSpec
from pyVmomi.vim.vsan.host import QueryVsanDisksSpec
from pyVmomi.vim.vsan.host import VsanHostCapability
from pyVmomi.vim.vsan.host import VsanManagedDisksInfo

class VsanVcDiskManagementSystem(ManagedObject):
   def RetrieveAllFlashCapabilities(self, cluster: ClusterComputeResource) -> list[VsanHostCapability]: ...
   def InitializeDiskMappings(self, spec: DiskMappingCreationSpec) -> Task: ...
   def QueryDiskMappings(self, host: HostSystem) -> list[DiskMapInfoEx]: ...
   def QueryVsanManagedDisks(self, host: HostSystem, filterSpec: Optional[QueryVsanDisksSpec]) -> Optional[VsanManagedDisksInfo]: ...
   def QueryClusterDataEfficiencyCapacityState(self, cluster: ClusterComputeResource) -> DataEfficiencyCapacityState: ...
   def RebuildDiskMapping(self, host: HostSystem, mapping: DiskMapping, maintenanceSpec: MaintenanceSpec) -> Task: ...
   def UnmountDiskMappingEx(self, cluster: ClusterComputeResource, mappings: list[DiskMapping], maintenanceSpec: MaintenanceSpec) -> Task: ...
   def RemoveDiskMappingEx(self, cluster: ClusterComputeResource, mappings: list[DiskMapping], maintenanceSpec: MaintenanceSpec) -> Task: ...
   def RemoveDiskEx(self, cluster: ClusterComputeResource, disks: list[ScsiDisk], maintenanceSpec: MaintenanceSpec) -> Task: ...
   def AddStoragePoolDisks(self, specs: list[AddStoragePoolDiskSpec]) -> Task: ...
   def DeleteStoragePoolDisk(self, cluster: ClusterComputeResource, spec: DeleteStoragePoolDiskSpec) -> Task: ...
   def UnmountStoragePoolDisks(self, cluster: ClusterComputeResource, spec: DeleteStoragePoolDiskSpec) -> Task: ...



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from .ContainerView import ContainerView as ContainerView
from .InventoryView import InventoryView as InventoryView
from .ListView import ListView as ListView
from .ManagedObjectView import ManagedObjectView as ManagedObjectView
from .View import View as View
from .ViewManager import ViewManager as ViewManager



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import ClassVar
from typing import Optional

from pyVmomi.VmomiSupport import Enum

from pyVmomi.vim import VirtualMachine

from pyVmomi.vmodl import DynamicData

from pyVmomi.vim.cluster import DasVmSettings

class DasVmConfigInfo(DynamicData):
   class Priority(Enum):
      disabled: ClassVar['Priority'] = 'disabled'
      low: ClassVar['Priority'] = 'low'
      medium: ClassVar['Priority'] = 'medium'
      high: ClassVar['Priority'] = 'high'

   key: VirtualMachine
   restartPriority: Optional[Priority] = None
   powerOffOnIsolation: Optional[bool] = None
   dasSettings: Optional[DasVmSettings] = None



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import ClassVar
from typing import Optional

from pyVmomi.VmomiSupport import Enum
from pyVmomi.VmomiSupport import ManagedObject
from pyVmomi.VmomiSupport import long

from pyVmomi.vim import Task

from pyVmomi.vmodl import DynamicData

class NvdimmSystem(ManagedObject):
   class RangeType(Enum):
      volatileRange: ClassVar['RangeType'] = 'volatileRange'
      persistentRange: ClassVar['RangeType'] = 'persistentRange'
      controlRange: ClassVar['RangeType'] = 'controlRange'
      blockRange: ClassVar['RangeType'] = 'blockRange'
      volatileVirtualDiskRange: ClassVar['RangeType'] = 'volatileVirtualDiskRange'
      volatileVirtualCDRange: ClassVar['RangeType'] = 'volatileVirtualCDRange'
      persistentVirtualDiskRange: ClassVar['RangeType'] = 'persistentVirtualDiskRange'
      persistentVirtualCDRange: ClassVar['RangeType'] = 'persistentVirtualCDRange'

   class NamespaceType(Enum):
      blockNamespace: ClassVar['NamespaceType'] = 'blockNamespace'
      persistentNamespace: ClassVar['NamespaceType'] = 'persistentNamespace'

   class HealthInfo(DynamicData):
      class StateFlag(Enum):
         normal: ClassVar['StateFlag'] = 'normal'
         error: ClassVar['StateFlag'] = 'error'

      healthStatus: str
      healthInformation: str
      stateFlagInfo: list[str] = []
      dimmTemperature: int
      dimmTemperatureThreshold: int
      spareBlocksPercentage: int
      spareBlockThreshold: int
      dimmLifespanPercentage: int
      esTemperature: Optional[int] = None
      esTemperatureThreshold: Optional[int] = None
      esLifespanPercentage: Optional[int] = None

   class RegionInfo(DynamicData):
      regionId: int
      setId: int
      rangeType: str
      startAddr: long
      size: long
      offset: long

   class Summary(DynamicData):
      numDimms: int
      healthStatus: str
      totalCapacity: long
      persistentCapacity: long
      blockCapacity: long
      availableCapacity: long
      numInterleavesets: int
      numNamespaces: int

   class DimmInfo(DynamicData):
      dimmHandle: int
      healthInfo: HealthInfo
      totalCapacity: long
      persistentCapacity: long
      availablePersistentCapacity: long
      volatileCapacity: long
      availableVolatileCapacity: long
      blockCapacity: long
      regionInfo: list[RegionInfo] = []
      representationString: str

   class InterleaveSetInfo(DynamicData):
      class InterleaveSetState(Enum):
         invalid: ClassVar['InterleaveSetState'] = 'invalid'
         active: ClassVar['InterleaveSetState'] = 'active'

      setId: int
      rangeType: str
      baseAddress: long
      size: long
      availableSize: long
      deviceList: list[int] = []
      state: str

   class Guid(DynamicData):
      uuid: str

   class NamespaceInfo(DynamicData):
      class NamespaceHealthStatus(Enum):
         normal: ClassVar['NamespaceHealthStatus'] = 'normal'
         missing: ClassVar['NamespaceHealthStatus'] = 'missing'
         labelMissing: ClassVar['NamespaceHealthStatus'] = 'labelMissing'
         interleaveBroken: ClassVar['NamespaceHealthStatus'] = 'interleaveBroken'
         labelInconsistent: ClassVar['NamespaceHealthStatus'] = 'labelInconsistent'
         bttCorrupt: ClassVar['NamespaceHealthStatus'] = 'bttCorrupt'
         badBlockSize: ClassVar['NamespaceHealthStatus'] = 'badBlockSize'

      class NamespaceState(Enum):
         invalid: ClassVar['NamespaceState'] = 'invalid'
         notInUse: ClassVar['NamespaceState'] = 'notInUse'
         inUse: ClassVar['NamespaceState'] = 'inUse'

      uuid: str
      friendlyName: str
      blockSize: long
      blockCount: long
      type: str
      namespaceHealthStatus: str
      locationID: int
      state: str

   class NamespaceDetails(DynamicData):
      class NamespaceHealthStatus(Enum):
         normal: ClassVar['NamespaceHealthStatus'] = 'normal'
         missing: ClassVar['NamespaceHealthStatus'] = 'missing'
         labelMissing: ClassVar['NamespaceHealthStatus'] = 'labelMissing'
         interleaveBroken: ClassVar['NamespaceHealthStatus'] = 'interleaveBroken'
         labelInconsistent: ClassVar['NamespaceHealthStatus'] = 'labelInconsistent'

      class NamespaceState(Enum):
         invalid: ClassVar['NamespaceState'] = 'invalid'
         notInUse: ClassVar['NamespaceState'] = 'notInUse'
         inUse: ClassVar['NamespaceState'] = 'inUse'

      uuid: str
      friendlyName: str
      size: long
      type: str
      namespaceHealthStatus: str
      interleavesetID: int
      state: str

   class NamespaceCreateSpec(DynamicData):
      friendlyName: Optional[str] = None
      blockSize: long
      blockCount: long
      type: str
      locationID: int

   class PMemNamespaceCreateSpec(DynamicData):
      friendlyName: Optional[str] = None
      size: long
      interleavesetID: int

   class NamespaceDeleteSpec(DynamicData):
      uuid: str

   class NvdimmSystemInfo(DynamicData):
      summary: Optional[Summary] = None
      dimms: list[int] = []
      dimmInfo: list[DimmInfo] = []
      interleaveSet: list[int] = []
      iSetInfo: list[InterleaveSetInfo] = []
      namespace: list[Guid] = []
      nsInfo: list[NamespaceInfo] = []
      nsDetails: list[NamespaceDetails] = []

   @property
   def nvdimmSystemInfo(self) -> NvdimmSystemInfo: ...

   def CreateNamespace(self, createSpec: NamespaceCreateSpec) -> Task: ...
   def CreatePMemNamespace(self, createSpec: PMemNamespaceCreateSpec) -> Task: ...
   def DeleteNamespace(self, deleteSpec: NamespaceDeleteSpec) -> Task: ...
   def DeleteBlockNamespaces(self) -> Task: ...



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import ClassVar
from typing import Optional

from pyVmomi.VmomiSupport import Enum

from pyVmomi.vim.event import VmEvent

class VmFailedStartingSecondaryEvent(VmEvent):
   class FailureReason(Enum):
      incompatibleHost: ClassVar['FailureReason'] = 'incompatibleHost'
      loginFailed: ClassVar['FailureReason'] = 'loginFailed'
      registerVmFailed: ClassVar['FailureReason'] = 'registerVmFailed'
      migrateFailed: ClassVar['FailureReason'] = 'migrateFailed'

   reason: Optional[str] = None



# Copyright (c) 2025 Broadcom. All Rights Reserved.
# The term "Broadcom" refers to Broadcom Inc. and/or its subsidiaries.

import sys

pyMajor = sys.version_info[0]
pyMinor = sys.version_info[1]

PY3 = pyMajor >= 3

if PY3:
    from http.client import (HTTPConnection, HTTPSConnection)
    from urllib.parse import urlparse

    binary_type = bytes
    str_type = str
    text_type = str

    def iteritems(d):
        return d.items()

    def itervalues(d):
        return d.values()

else:
    from httplib import (HTTPConnection, HTTPSConnection)
    from urlparse import urlparse

    binary_type = str
    str_type = basestring
    text_type = unicode

    def iteritems(d):
        return d.iteritems()

    def itervalues(d):
        return d.itervalues()

    import itertools  # noqa: E402

    map = itertools.imap
    range = xrange
    zip = itertools.izip



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import Optional

from pyVmomi.vim import ManagedEntity

from pyVmomi.vmodl import DynamicData
from pyVmomi.vmodl import KeyAnyValue
from pyVmomi.vmodl import LocalizableMessage

class EntityCompatibilityResult(DynamicData):
   entity: ManagedEntity
   compatible: bool
   incompatibleReasons: list[LocalizableMessage] = []
   extendedAttributes: list[KeyAnyValue] = []



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import ClassVar
from typing import Optional

from pyVmomi.VmomiSupport import Enum

from pyVmomi.vim import Datastore

from pyVmomi.vmodl import DynamicData

class SystemVMsConfigInfo(DynamicData):
   class DeploymentMode(Enum):
      SYSTEM_MANAGED: ClassVar['DeploymentMode'] = 'SYSTEM_MANAGED'
      ABSENT: ClassVar['DeploymentMode'] = 'ABSENT'

   allowedDatastores: list[Datastore] = []
   notAllowedDatastores: list[Datastore] = []
   dsTagCategoriesToExclude: list[str] = []
   deploymentMode: Optional[str] = None



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import ClassVar
from typing import Optional

from pyVmomi.VmomiSupport import Enum

from pyVmomi.vim import HostSystem

from pyVmomi.vmodl import DynamicData

from pyVmomi.vim.dvs import KeyedOpaqueBlob
from pyVmomi.vim.dvs import ProductSpec

class HostMember(DynamicData):
   class HostComponentState(Enum):
      up: ClassVar['HostComponentState'] = 'up'
      pending: ClassVar['HostComponentState'] = 'pending'
      outOfSync: ClassVar['HostComponentState'] = 'outOfSync'
      warning: ClassVar['HostComponentState'] = 'warning'
      disconnected: ClassVar['HostComponentState'] = 'disconnected'
      down: ClassVar['HostComponentState'] = 'down'

   class ConfigSpec(DynamicData):
      operation: str
      host: HostSystem
      backing: Optional[Backing] = None
      maxProxySwitchPorts: Optional[int] = None
      vendorSpecificConfig: list[KeyedOpaqueBlob] = []

   class PnicSpec(DynamicData):
      pnicDevice: str
      uplinkPortKey: Optional[str] = None
      uplinkPortgroupKey: Optional[str] = None
      connectionCookie: Optional[int] = None

   class Backing(DynamicData):
      pass

   class PnicBacking(Backing):
      pnicSpec: list[PnicSpec] = []

   class RuntimeState(DynamicData):
      currentMaxProxySwitchPorts: int

   class TransportZoneType(Enum):
      vlan: ClassVar['TransportZoneType'] = 'vlan'
      overlay: ClassVar['TransportZoneType'] = 'overlay'

   class TransportZoneInfo(DynamicData):
      uuid: str
      type: str

   class ConfigInfo(DynamicData):
      host: Optional[HostSystem] = None
      maxProxySwitchPorts: int
      vendorSpecificConfig: list[KeyedOpaqueBlob] = []
      backing: Backing
      nsxSwitch: Optional[bool] = None
      ensEnabled: Optional[bool] = None
      ensInterruptEnabled: Optional[bool] = None
      transportZones: list[TransportZoneInfo] = []
      nsxtUsedUplinkNames: list[str] = []
      networkOffloadingEnabled: Optional[bool] = None

   class HostUplinkState(DynamicData):
      class State(Enum):
         active: ClassVar['State'] = 'active'
         standby: ClassVar['State'] = 'standby'

      uplinkName: str
      state: str

   class RuntimeInfo(DynamicData):
      host: HostSystem
      status: Optional[str] = None
      statusDetail: Optional[str] = None
      nsxtStatus: Optional[str] = None
      nsxtStatusDetail: Optional[str] = None
      healthCheckResult: list[HealthCheckResult] = []
      hostUplinkState: list[HostUplinkState] = []

   class HealthCheckResult(DynamicData):
      summary: Optional[str] = None

   class UplinkHealthCheckResult(HealthCheckResult):
      uplinkPortKey: str

   runtimeState: Optional[RuntimeState] = None
   config: ConfigInfo
   productInfo: Optional[ProductSpec] = None
   uplinkPortKey: list[str] = []
   status: str
   statusDetail: Optional[str] = None



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import Optional

from pyVmomi.VmomiSupport import long

from pyVmomi.vim import KeyValue

from pyVmomi.vmodl import DynamicData

from pyVmomi.vim.dvs import HostMember

from pyVmomi.vim.host import PhysicalNic

class HostProxySwitch(DynamicData):
   class Specification(DynamicData):
      backing: Optional[HostMember.Backing] = None

   class Config(DynamicData):
      changeOperation: Optional[str] = None
      uuid: str
      spec: Optional[Specification] = None

   class HostLagConfig(DynamicData):
      lagKey: str
      lagName: Optional[str] = None
      uplinkPort: list[KeyValue] = []

   class EnsInfo(DynamicData):
      opsVersion: long
      numPSOps: long
      numLcoreOps: long
      errorStatus: long
      lcoreStatus: long

   dvsUuid: str
   dvsName: str
   key: str
   numPorts: int
   configNumPorts: Optional[int] = None
   numPortsAvailable: int
   uplinkPort: list[KeyValue] = []
   mtu: Optional[int] = None
   pnic: list[PhysicalNic] = []
   spec: Specification
   hostLag: list[HostLagConfig] = []
   networkReservationSupported: Optional[bool] = None
   nsxtEnabled: Optional[bool] = None
   ensEnabled: Optional[bool] = None
   ensInterruptEnabled: Optional[bool] = None
   transportZones: list[HostMember.TransportZoneInfo] = []
   nsxUsedUplinkPort: list[str] = []
   nsxtStatus: Optional[str] = None
   nsxtStatusDetail: Optional[str] = None
   ensInfo: Optional[EnsInfo] = None
   networkOffloadingEnabled: Optional[bool] = None
   hostUplinkState: list[HostMember.HostUplinkState] = []



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import ClassVar
from typing import Optional

from pyVmomi.VmomiSupport import Enum
from pyVmomi.VmomiSupport import ManagedObject
from pyVmomi.VmomiSupport import long

from pyVmomi.vim import Datastore
from pyVmomi.vim import HostSystem
from pyVmomi.vim import ImportSpec
from pyVmomi.vim import KeyValue
from pyVmomi.vim import ManagedEntity
from pyVmomi.vim import Network
from pyVmomi.vim import OvfConsumer
from pyVmomi.vim import ResourceConfigSpec
from pyVmomi.vim import ResourcePool

from pyVmomi.vmodl import DynamicData
from pyVmomi.vmodl import LocalizableMessage
from pyVmomi.vmodl import MethodFault

from pyVmomi.vim.vApp import ProductInfo
from pyVmomi.vim.vApp import PropertyInfo

from pyVmomi.vim.vm import Snapshot

class OvfManager(ManagedObject):
   class OvfOptionInfo(DynamicData):
      option: str
      description: LocalizableMessage

   class DeploymentOption(DynamicData):
      key: str
      label: str
      description: str

   class CommonParams(DynamicData):
      locale: str
      deploymentOption: str
      msgBundle: list[KeyValue] = []
      importOption: list[str] = []

   class ValidateHostParams(CommonParams):
      pass

   class ValidateHostResult(DynamicData):
      downloadSize: Optional[long] = None
      flatDeploymentSize: Optional[long] = None
      sparseDeploymentSize: Optional[long] = None
      error: list[MethodFault] = []
      warning: list[MethodFault] = []
      supportedDiskProvisioning: list[str] = []

   class ParseDescriptorParams(CommonParams):
      pass

   class ParseDescriptorResult(DynamicData):
      eula: list[str] = []
      network: list[NetworkInfo] = []
      ipAllocationScheme: list[str] = []
      ipProtocols: list[str] = []
      property: list[PropertyInfo] = []
      productInfo: Optional[ProductInfo] = None
      annotation: str
      approximateDownloadSize: Optional[long] = None
      approximateFlatDeploymentSize: Optional[long] = None
      approximateSparseDeploymentSize: Optional[long] = None
      defaultEntityName: str
      virtualApp: bool
      deploymentOption: list[DeploymentOption] = []
      defaultDeploymentOption: str
      entityName: list[KeyValue] = []
      annotatedOst: Optional[OvfConsumer.OstNode] = None
      error: list[MethodFault] = []
      warning: list[MethodFault] = []

   class NetworkInfo(DynamicData):
      name: str
      description: str

   class CreateImportSpecParams(CommonParams):
      class DiskProvisioningType(Enum):
         monolithicSparse: ClassVar['DiskProvisioningType'] = 'monolithicSparse'
         monolithicFlat: ClassVar['DiskProvisioningType'] = 'monolithicFlat'
         twoGbMaxExtentSparse: ClassVar['DiskProvisioningType'] = 'twoGbMaxExtentSparse'
         twoGbMaxExtentFlat: ClassVar['DiskProvisioningType'] = 'twoGbMaxExtentFlat'
         thin: ClassVar['DiskProvisioningType'] = 'thin'
         thick: ClassVar['DiskProvisioningType'] = 'thick'
         seSparse: ClassVar['DiskProvisioningType'] = 'seSparse'
         eagerZeroedThick: ClassVar['DiskProvisioningType'] = 'eagerZeroedThick'
         sparse: ClassVar['DiskProvisioningType'] = 'sparse'
         flat: ClassVar['DiskProvisioningType'] = 'flat'

      entityName: str
      hostSystem: Optional[HostSystem] = None
      networkMapping: list[NetworkMapping] = []
      ipAllocationPolicy: Optional[str] = None
      ipProtocol: Optional[str] = None
      propertyMapping: list[KeyValue] = []
      resourceMapping: list[ResourceMap] = []
      diskProvisioning: Optional[str] = None
      instantiationOst: Optional[OvfConsumer.OstNode] = None

   class ResourceMap(DynamicData):
      source: str
      parent: Optional[ResourcePool] = None
      resourceSpec: Optional[ResourceConfigSpec] = None
      datastore: Optional[Datastore] = None

   class NetworkMapping(DynamicData):
      name: str
      network: Network

   class DatastoreMapping(DynamicData):
      diskId: str
      datastore: Datastore

   class StorageProfileMapping(DynamicData):
      diskId: str
      storageProfileId: str

   class CreateImportSpecResult(DynamicData):
      importSpec: Optional[ImportSpec] = None
      fileItem: list[FileItem] = []
      warning: list[MethodFault] = []
      error: list[MethodFault] = []

   class FileItem(DynamicData):
      deviceId: str
      path: str
      compressionMethod: Optional[str] = None
      chunkSize: Optional[long] = None
      size: Optional[long] = None
      cimType: int
      create: bool

   class CreateDescriptorParams(DynamicData):
      ovfFiles: list[OvfFile] = []
      name: Optional[str] = None
      description: Optional[str] = None
      includeImageFiles: Optional[bool] = None
      exportOption: list[str] = []
      snapshot: Optional[Snapshot] = None

   class CreateDescriptorResult(DynamicData):
      ovfDescriptor: str
      error: list[MethodFault] = []
      warning: list[MethodFault] = []
      includeImageFiles: Optional[bool] = None

   class OvfFile(DynamicData):
      deviceId: str
      path: str
      compressionMethod: Optional[str] = None
      chunkSize: Optional[long] = None
      size: long
      capacity: Optional[long] = None
      populatedSize: Optional[long] = None

   class OvfImportParams(CreateImportSpecParams):
      pushMode: Optional[bool] = None
      signatureRequired: Optional[bool] = None
      skipManifestCheck: Optional[bool] = None
      powerOn: Optional[bool] = None
      customHttpHeaders: list[KeyValue] = []
      sourceCertificate: Optional[str] = None
      datastoreMappings: list[DatastoreMapping] = []
      vmProfile: Optional[str] = None
      diskProfiles: list[StorageProfileMapping] = []

   @property
   def ovfImportOption(self) -> list[OvfOptionInfo]: ...
   @property
   def ovfExportOption(self) -> list[OvfOptionInfo]: ...

   def ValidateHost(self, ovfDescriptor: str, host: HostSystem, vhp: ValidateHostParams) -> ValidateHostResult: ...
   def ParseDescriptor(self, ovfDescriptor: str, pdp: ParseDescriptorParams) -> ParseDescriptorResult: ...
   def CreateImportSpec(self, ovfDescriptor: str, resourcePool: ResourcePool, datastore: Datastore, cisp: CreateImportSpecParams) -> CreateImportSpecResult: ...
   def CreateDescriptor(self, obj: ManagedEntity, cdp: CreateDescriptorParams) -> CreateDescriptorResult: ...



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from datetime import datetime

from typing import ClassVar
from typing import NoReturn
from typing import Optional

from pyVmomi.VmomiSupport import Enum
from pyVmomi.VmomiSupport import long

from pyVmomi.vim import Datastore
from pyVmomi.vim import HostServiceTicket
from pyVmomi.vim import LicenseManager
from pyVmomi.vim import ManagedEntity
from pyVmomi.vim import Network
from pyVmomi.vim import Task
from pyVmomi.vim import VirtualMachine

from pyVmomi.vmodl import DynamicData

from pyVmomi.vim.encryption import CryptoKeyId
from pyVmomi.vim.encryption import CryptoKeyPlain

from pyVmomi.vim.host import Capability
from pyVmomi.vim.host import ConfigInfo
from pyVmomi.vim.host import ConfigManager
from pyVmomi.vim.host import ConnectInfo
from pyVmomi.vim.host import ConnectSpec
from pyVmomi.vim.host import DatastoreBrowser
from pyVmomi.vim.host import FlagInfo
from pyVmomi.vim.host import HardwareInfo
from pyVmomi.vim.host import IpmiInfo
from pyVmomi.vim.host import MaintenanceSpec
from pyVmomi.vim.host import RuntimeInfo
from pyVmomi.vim.host import Summary
from pyVmomi.vim.host import SystemResourceInfo
from pyVmomi.vim.host import SystemSwapConfiguration
from pyVmomi.vim.host import TpmAttestationReport

from pyVmomi.vim.profile import ComplianceResult

from pyVmomi.vim.vm import ConfigInfo

from pyVmomi.vim.profile.host import AnswerFileStatusResult
from pyVmomi.vim.profile.host import ProfileManager

class HostSystem(ManagedEntity):
   class ConnectionState(Enum):
      connected: ClassVar['ConnectionState'] = 'connected'
      notResponding: ClassVar['ConnectionState'] = 'notResponding'
      disconnected: ClassVar['ConnectionState'] = 'disconnected'

   class PowerState(Enum):
      poweredOn: ClassVar['PowerState'] = 'poweredOn'
      poweredOff: ClassVar['PowerState'] = 'poweredOff'
      standBy: ClassVar['PowerState'] = 'standBy'
      unknown: ClassVar['PowerState'] = 'unknown'

   class StandbyMode(Enum):
      entering: ClassVar['StandbyMode'] = 'entering'
      exiting: ClassVar['StandbyMode'] = 'exiting'
      # Reserved python keyword: commenting out.
      # in: ClassVar['StandbyMode'] = 'in'
      none: ClassVar['StandbyMode'] = 'none'

   class CryptoState(Enum):
      incapable: ClassVar['CryptoState'] = 'incapable'
      prepared: ClassVar['CryptoState'] = 'prepared'
      safe: ClassVar['CryptoState'] = 'safe'
      pendingIncapable: ClassVar['CryptoState'] = 'pendingIncapable'

   class RemediationState(DynamicData):
      class State(Enum):
         remediationReady: ClassVar['State'] = 'remediationReady'
         precheckRemediationRunning: ClassVar['State'] = 'precheckRemediationRunning'
         precheckRemediationComplete: ClassVar['State'] = 'precheckRemediationComplete'
         precheckRemediationFailed: ClassVar['State'] = 'precheckRemediationFailed'
         remediationRunning: ClassVar['State'] = 'remediationRunning'
         remediationFailed: ClassVar['State'] = 'remediationFailed'

      state: str
      operationTime: datetime

   class ComplianceCheckState(DynamicData):
      state: str
      checkTime: datetime

   class ReconnectSpec(DynamicData):
      syncState: Optional[bool] = None

   @property
   def runtime(self) -> RuntimeInfo: ...
   @property
   def summary(self) -> Summary: ...
   @property
   def hardware(self) -> Optional[HardwareInfo]: ...
   @property
   def capability(self) -> Optional[Capability]: ...
   @property
   def licensableResource(self) -> LicenseManager.LicensableResourceInfo: ...
   @property
   def remediationState(self) -> Optional[RemediationState]: ...
   @property
   def precheckRemediationResult(self) -> Optional[ProfileManager.ApplyHostConfigSpec]: ...
   @property
   def remediationResult(self) -> Optional[ProfileManager.ApplyHostConfigResult]: ...
   @property
   def complianceCheckState(self) -> Optional[ComplianceCheckState]: ...
   @property
   def complianceCheckResult(self) -> Optional[ComplianceResult]: ...
   @property
   def configManager(self) -> ConfigManager: ...
   @property
   def config(self) -> Optional[ConfigInfo]: ...
   @property
   def vm(self) -> list[VirtualMachine]: ...
   @property
   def datastore(self) -> list[Datastore]: ...
   @property
   def network(self) -> list[Network]: ...
   @property
   def datastoreBrowser(self) -> DatastoreBrowser: ...
   @property
   def systemResources(self) -> Optional[SystemResourceInfo]: ...
   @property
   def answerFileValidationState(self) -> Optional[AnswerFileStatusResult]: ...
   @property
   def answerFileValidationResult(self) -> Optional[AnswerFileStatusResult]: ...

   def QueryTpmAttestationReport(self) -> Optional[TpmAttestationReport]: ...
   def QueryConnectionInfo(self) -> ConnectInfo: ...
   def UpdateSystemResources(self, resourceInfo: SystemResourceInfo) -> NoReturn: ...
   def UpdateSystemSwapConfiguration(self, sysSwapConfig: SystemSwapConfiguration) -> NoReturn: ...
   def Reconnect(self, cnxSpec: Optional[ConnectSpec], reconnectSpec: Optional[ReconnectSpec]) -> Task: ...
   def Disconnect(self) -> Task: ...
   def EnterMaintenanceMode(self, timeout: int, evacuatePoweredOffVms: Optional[bool], maintenanceSpec: Optional[MaintenanceSpec]) -> Task: ...
   def ExitMaintenanceMode(self, timeout: int) -> Task: ...
   def Reboot(self, force: bool) -> Task: ...
   def Shutdown(self, force: bool) -> Task: ...
   def EnterStandbyMode(self, timeoutSec: int, evacuatePoweredOffVms: Optional[bool]) -> Task: ...
   def ExitStandbyMode(self, timeoutSec: int) -> Task: ...
   def QueryOverhead(self, memorySize: long, videoRamSize: Optional[int], numVcpus: int) -> long: ...
   def QueryOverheadEx(self, vmConfigInfo: ConfigInfo) -> long: ...
   def ReconfigureDAS(self) -> Task: ...
   def UpdateFlags(self, flagInfo: FlagInfo) -> NoReturn: ...
   def EnterLockdownMode(self) -> NoReturn: ...
   def ExitLockdownMode(self) -> NoReturn: ...
   def AcquireCimServicesTicket(self) -> HostServiceTicket: ...
   def UpdateIpmi(self, ipmiInfo: IpmiInfo) -> NoReturn: ...
   def RetrieveHardwareUptime(self) -> long: ...
   def PrepareCrypto(self) -> NoReturn: ...
   def EnableCrypto(self, keyPlain: CryptoKeyPlain) -> NoReturn: ...
   def ConfigureCryptoKey(self, keyId: Optional[CryptoKeyId]) -> NoReturn: ...
   def QueryProductLockerLocation(self) -> str: ...
   def UpdateProductLockerLocation(self, path: str) -> Task: ...
   def RetrieveFreeEpcMemory(self) -> long: ...



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import ClassVar
from typing import Optional

from pyVmomi.VmomiSupport import Enum

from pyVmomi.vim.fault import VmFaultToleranceIssue

class VmFaultToleranceInvalidFileBacking(VmFaultToleranceIssue):
   class DeviceType(Enum):
      virtualFloppy: ClassVar['DeviceType'] = 'virtualFloppy'
      virtualCdrom: ClassVar['DeviceType'] = 'virtualCdrom'
      virtualSerialPort: ClassVar['DeviceType'] = 'virtualSerialPort'
      virtualParallelPort: ClassVar['DeviceType'] = 'virtualParallelPort'
      virtualDisk: ClassVar['DeviceType'] = 'virtualDisk'

   backingType: Optional[str] = None
   backingFilename: Optional[str] = None



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import NoReturn
from typing import Optional

from pyVmomi.VmomiSupport import ManagedObject

from pyVmomi.vim import ClusterComputeResource
from pyVmomi.vim import HostSystem

from pyVmomi.vmodl import DynamicData
from pyVmomi.vmodl import MethodFault

from pyVmomi.vim.vm.device import VirtualPCIPassthrough

class DirectPathProfileManager(ManagedObject):
   class DirectPathConfig(DynamicData):
      pass

   class VmiopDirectPathConfig(DirectPathConfig):
      vgpuProfile: str

   class DvxDirectPathConfig(DirectPathConfig):
      dvxBacking: VirtualPCIPassthrough.DvxBackingInfo

   class DynamicDirectPathConfig(DirectPathConfig):
      dynamicDirectPathBacking: VirtualPCIPassthrough.DynamicBackingInfo

   class VirtualDeviceGroupDirectPathConfig(DirectPathConfig):
      deviceGroupName: str

   class CreateSpec(DynamicData):
      name: str
      description: Optional[str] = None
      deviceConfig: DirectPathConfig

   class UpdateSpec(DynamicData):
      name: Optional[str] = None
      description: Optional[str] = None

   class FilterSpec(DynamicData):
      ids: list[str] = []
      names: list[str] = []
      clusters: list[ClusterComputeResource] = []

   class DirectPathProfileInfo(DynamicData):
      id: str
      name: str
      description: Optional[str] = None
      vendorName: str
      deviceConfig: DirectPathConfig

   class TargetEntity(DynamicData):
      pass

   class TargetHost(TargetEntity):
      host: HostSystem

   class TargetCluster(TargetEntity):
      cluster: ClusterComputeResource

   class CapacityQuerySpec(DynamicData):
      pass

   class CapacityQueryById(CapacityQuerySpec):
      id: str

   class CapacityQueryByName(CapacityQuerySpec):
      name: str

   class CapacityQueryByDeviceConfig(CapacityQuerySpec):
      deviceConfig: DirectPathConfig

   class CapacityResult(DynamicData):
      pass

   class CapacityInfo(CapacityResult):
      profile: DirectPathProfileInfo
      consumed: int
      remaining: int
      max: int
      unusedReservation: int

   class CapacityUnknown(CapacityResult):
      querySpec: CapacityQuerySpec
      faultList: list[MethodFault] = []

   def CreateDirectPathProfile(self, spec: CreateSpec) -> str: ...
   def UpdateDirectPathProfile(self, id: str, spec: UpdateSpec) -> NoReturn: ...
   def DeleteDirectPathProfile(self, id: str) -> NoReturn: ...
   def ListDirectPathProfiles(self, filterSpec: FilterSpec) -> list[DirectPathProfileInfo]: ...
   def QueryDirectPathProfileCapacity(self, target: TargetEntity, querySpec: list[CapacityQuerySpec]) -> list[CapacityResult]: ...



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import Optional

from pyVmomi.VmomiSupport import long

from pyVmomi.vmodl import DynamicData
from pyVmomi.vmodl import MethodFault

from pyVmomi.pbm.placement import MatchingResources
from pyVmomi.pbm.placement import PlacementHub
from pyVmomi.pbm.placement import ResourceUtilization

class CompatibilityResult(DynamicData):
   hub: PlacementHub
   matchingResources: list[MatchingResources] = []
   howMany: Optional[long] = None
   utilization: list[ResourceUtilization] = []
   warning: list[MethodFault] = []
   error: list[MethodFault] = []



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from datetime import datetime

from typing import Optional

from pyVmomi.vim import ClusterComputeResource

from pyVmomi.vmodl import DynamicData

class VsanHistoricalHealthQuerySpec(DynamicData):
   clusters: list[ClusterComputeResource] = []
   start: datetime
   end: Optional[datetime] = None
   testId: Optional[str] = None
   groupId: Optional[str] = None
   includeHealthRemediation: Optional[bool] = None



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import Optional

from pyVmomi.VmomiSupport import ManagedObject

from pyVmomi.vim import ManagedEntity

from pyVmomi.vim.scheduler import ScheduledTask
from pyVmomi.vim.scheduler import ScheduledTaskDescription
from pyVmomi.vim.scheduler import ScheduledTaskSpec

class ScheduledTaskManager(ManagedObject):
   @property
   def scheduledTask(self) -> list[ScheduledTask]: ...
   @property
   def description(self) -> ScheduledTaskDescription: ...

   def Create(self, entity: ManagedEntity, spec: ScheduledTaskSpec) -> ScheduledTask: ...
   def RetrieveEntityScheduledTask(self, entity: Optional[ManagedEntity]) -> list[ScheduledTask]: ...
   def CreateObjectScheduledTask(self, obj: ManagedObject, spec: ScheduledTaskSpec) -> ScheduledTask: ...
   def RetrieveObjectScheduledTask(self, obj: Optional[ManagedObject]) -> list[ScheduledTask]: ...



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from pyVmomi.vim import DistributedVirtualSwitch
from pyVmomi.vim import HostSystem

from pyVmomi.vim.vsan import VsanNetworkConfigBaseIssue

class VsanNetworkConfigVdsScopeIssue(VsanNetworkConfigBaseIssue):
   vds: DistributedVirtualSwitch
   memberHosts: list[HostSystem] = []
   nonMemberHosts: list[HostSystem] = []



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import ClassVar
from typing import Optional

from pyVmomi.VmomiSupport import Enum

from pyVmomi.vmodl import DynamicData
from pyVmomi.vmodl import KeyAnyValue

from pyVmomi.vim.host import FcoeConfig
from pyVmomi.vim.host import IpConfig
from pyVmomi.vim.host import RdmaDevice

class PhysicalNic(DynamicData):
   class Specification(DynamicData):
      ip: Optional[IpConfig] = None
      linkSpeed: Optional[LinkSpeedDuplex] = None
      enableEnhancedNetworkingStack: Optional[bool] = None
      ensInterruptEnabled: Optional[bool] = None

   class Config(DynamicData):
      device: str
      spec: Specification

   class LinkSpeedDuplex(DynamicData):
      speedMb: int
      duplex: bool

   class NetworkHint(DynamicData):
      class HintElement(DynamicData):
         vlanId: Optional[int] = None

      class IpNetwork(NetworkHint.HintElement):
         ipSubnet: str

      class NamedNetwork(NetworkHint.HintElement):
         network: str

      device: str
      subnet: list[IpNetwork] = []
      network: list[NamedNetwork] = []
      connectedSwitchPort: Optional[CdpInfo] = None
      lldpInfo: Optional[LldpInfo] = None

   class CdpDeviceCapability(DynamicData):
      router: bool
      transparentBridge: bool
      sourceRouteBridge: bool
      networkSwitch: bool
      host: bool
      igmpEnabled: bool
      repeater: bool

   class CdpInfo(DynamicData):
      cdpVersion: Optional[int] = None
      timeout: Optional[int] = None
      ttl: Optional[int] = None
      samples: Optional[int] = None
      devId: Optional[str] = None
      address: Optional[str] = None
      portId: Optional[str] = None
      deviceCapability: Optional[CdpDeviceCapability] = None
      softwareVersion: Optional[str] = None
      hardwarePlatform: Optional[str] = None
      ipPrefix: Optional[str] = None
      ipPrefixLen: Optional[int] = None
      vlan: Optional[int] = None
      fullDuplex: Optional[bool] = None
      mtu: Optional[int] = None
      systemName: Optional[str] = None
      systemOID: Optional[str] = None
      mgmtAddr: Optional[str] = None
      location: Optional[str] = None

   class LldpInfo(DynamicData):
      chassisId: str
      portId: str
      timeToLive: int
      parameter: list[KeyAnyValue] = []

   class VmDirectPathGen2SupportedMode(Enum):
      upt: ClassVar['VmDirectPathGen2SupportedMode'] = 'upt'

   class ResourcePoolSchedulerDisallowedReason(Enum):
      userOptOut: ClassVar['ResourcePoolSchedulerDisallowedReason'] = 'userOptOut'
      hardwareUnsupported: ClassVar['ResourcePoolSchedulerDisallowedReason'] = 'hardwareUnsupported'

   key: Optional[str] = None
   device: str
   pci: str
   driver: Optional[str] = None
   driverVersion: Optional[str] = None
   firmwareVersion: Optional[str] = None
   linkSpeed: Optional[LinkSpeedDuplex] = None
   validLinkSpecification: list[LinkSpeedDuplex] = []
   spec: Specification
   wakeOnLanSupported: bool
   mac: str
   fcoeConfiguration: Optional[FcoeConfig] = None
   vmDirectPathGen2Supported: Optional[bool] = None
   vmDirectPathGen2SupportedMode: Optional[str] = None
   resourcePoolSchedulerAllowed: Optional[bool] = None
   resourcePoolSchedulerDisallowedReason: list[str] = []
   autoNegotiateSupported: Optional[bool] = None
   enhancedNetworkingStackSupported: Optional[bool] = None
   ensInterruptSupported: Optional[bool] = None
   rdmaDevice: Optional[RdmaDevice] = None
   dpuId: Optional[str] = None



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import Optional

from pyVmomi.pbm import AboutInfo

from pyVmomi.vmodl import DynamicData

from pyVmomi.pbm.auth import SessionManager

from pyVmomi.pbm.capability import CapabilityMetadataManager

from pyVmomi.pbm.compliance import ComplianceManager

from pyVmomi.pbm.placement import PlacementSolver

from pyVmomi.pbm.profile import ProfileManager

from pyVmomi.pbm.replication import ReplicationManager

class ServiceInstanceContent(DynamicData):
   aboutInfo: AboutInfo
   sessionManager: SessionManager
   capabilityMetadataManager: CapabilityMetadataManager
   profileManager: ProfileManager
   complianceManager: ComplianceManager
   placementSolver: PlacementSolver
   replicationManager: Optional[ReplicationManager] = None



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import ClassVar
from typing import Optional

from pyVmomi.VmomiSupport import Enum
from pyVmomi.VmomiSupport import byte

from pyVmomi.vmodl import DynamicData

class DigestInfo(DynamicData):
   class DigestMethodType(Enum):
      SHA1: ClassVar['DigestMethodType'] = 'SHA1'
      MD5: ClassVar['DigestMethodType'] = 'MD5'
      SHA256: ClassVar['DigestMethodType'] = 'SHA256'
      SHA384: ClassVar['DigestMethodType'] = 'SHA384'
      SHA512: ClassVar['DigestMethodType'] = 'SHA512'
      SM3_256: ClassVar['DigestMethodType'] = 'SM3_256'

   digestMethod: str
   digestValue: list[byte] = []
   objectName: Optional[str] = None



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import Optional

from pyVmomi.VmomiSupport import ManagedObject

from pyVmomi.vim import DistributedVirtualSwitch
from pyVmomi.vim import HostSystem
from pyVmomi.vim import ManagedEntity
from pyVmomi.vim import SelectionSet
from pyVmomi.vim import Task

from pyVmomi.vmodl import DynamicData
from pyVmomi.vmodl import MethodFault

from pyVmomi.vim.dvs import DistributedVirtualPortgroup
from pyVmomi.vim.dvs import DistributedVirtualPortgroupInfo
from pyVmomi.vim.dvs import DistributedVirtualSwitchInfo
from pyVmomi.vim.dvs import EntityBackup
from pyVmomi.vim.dvs import HostProductSpec
from pyVmomi.vim.dvs import NetworkOffloadSpec
from pyVmomi.vim.dvs import ProductSpec

from pyVmomi.vim.fault import ImportOperationBulkFault

from pyVmomi.vim.host import PhysicalNic

class DistributedVirtualSwitchManager(ManagedObject):
   class PhysicalNicsList(DynamicData):
      host: HostSystem
      physicalNics: list[PhysicalNic] = []

   class DvsConfigTarget(DynamicData):
      distributedVirtualPortgroup: list[DistributedVirtualPortgroupInfo] = []
      distributedVirtualSwitch: list[DistributedVirtualSwitchInfo] = []

   class CompatibilityResult(DynamicData):
      host: HostSystem
      error: list[MethodFault] = []

   class HostContainer(DynamicData):
      container: ManagedEntity
      recursive: bool

   class HostDvsFilterSpec(DynamicData):
      inclusive: bool

   class HostArrayFilter(HostDvsFilterSpec):
      host: list[HostSystem] = []

   class HostContainerFilter(HostDvsFilterSpec):
      hostContainer: HostContainer

   class HostDvsMembershipFilter(HostDvsFilterSpec):
      distributedVirtualSwitch: DistributedVirtualSwitch

   class DvsProductSpec(DynamicData):
      newSwitchProductSpec: Optional[ProductSpec] = None
      distributedVirtualSwitch: Optional[DistributedVirtualSwitch] = None

   class ImportResult(DynamicData):
      distributedVirtualSwitch: list[DistributedVirtualSwitch] = []
      distributedVirtualPortgroup: list[DistributedVirtualPortgroup] = []
      importFault: list[ImportOperationBulkFault.FaultOnImport] = []

   def QuerySupportedSwitchSpec(self, recommended: Optional[bool]) -> list[ProductSpec]: ...
   def QuerySupportedNetworkOffloadSpec(self, switchProductSpec: ProductSpec) -> list[NetworkOffloadSpec]: ...
   def QueryCompatibleVmnicsFromHosts(self, hosts: list[HostSystem], dvs: DistributedVirtualSwitch) -> list[PhysicalNicsList]: ...
   def QueryCompatibleHostForNewDvs(self, container: ManagedEntity, recursive: bool, switchProductSpec: Optional[ProductSpec]) -> list[HostSystem]: ...
   def QueryCompatibleHostForExistingDvs(self, container: ManagedEntity, recursive: bool, dvs: DistributedVirtualSwitch) -> list[HostSystem]: ...
   def QueryCompatibleHostSpec(self, switchProductSpec: Optional[ProductSpec]) -> list[HostProductSpec]: ...
   def QueryFeatureCapability(self, switchProductSpec: Optional[ProductSpec]) -> Optional[DistributedVirtualSwitch.FeatureCapability]: ...
   def QuerySwitchByUuid(self, uuid: str) -> Optional[DistributedVirtualSwitch]: ...
   def QueryDvsConfigTarget(self, host: Optional[HostSystem], dvs: Optional[DistributedVirtualSwitch]) -> DvsConfigTarget: ...
   def CheckCompatibility(self, hostContainer: HostContainer, dvsProductSpec: Optional[DvsProductSpec], hostFilterSpec: list[HostDvsFilterSpec]) -> list[CompatibilityResult]: ...
   def RectifyHost(self, hosts: list[HostSystem]) -> Task: ...
   def ExportEntity(self, selectionSet: list[SelectionSet]) -> Task: ...
   def ImportEntity(self, entityBackup: list[EntityBackup.Config], importType: str) -> Task: ...
   def LookupPortgroup(self, switchUuid: str, portgroupKey: str) -> Optional[DistributedVirtualPortgroup]: ...



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from datetime import datetime

from typing import Optional

from pyVmomi.sms.storage.replication import GroupOperationResult
from pyVmomi.sms.storage.replication import PointInTimeReplicaId

class SyncReplicationGroupSuccessResult(GroupOperationResult):
   timeStamp: datetime
   pitId: Optional[PointInTimeReplicaId] = None
   pitName: Optional[str] = None



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import Optional

from pyVmomi.vmodl import DynamicData
from pyVmomi.vmodl import MethodFault

from pyVmomi.vim.host import VsanSmartParameter

class VsanSmartDiskStats(DynamicData):
   disk: str
   stats: list[VsanSmartParameter] = []
   error: Optional[MethodFault] = None



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import Optional

from pyVmomi.vim.vsan import DataEfficiencyConfig
from pyVmomi.vim.vsan import DatastoreConfig
from pyVmomi.vim.vsan import MetricsConfig
from pyVmomi.vim.vsan import RdmaConfig
from pyVmomi.vim.vsan import ResyncIopsInfo
from pyVmomi.vim.vsan import SnapServiceConfig
from pyVmomi.vim.vsan import VsanDeconvergedNetConfig
from pyVmomi.vim.vsan import VsanExtendedConfig
from pyVmomi.vim.vsan import VsanInternalExtendedConfig
from pyVmomi.vim.vsan import VsanUnmapConfig
from pyVmomi.vim.vsan import WitnessHostConfig

from pyVmomi.vim.vsan.host import ConfigInfo
from pyVmomi.vim.vsan.host import DataInTransitEncryptionInfo
from pyVmomi.vim.vsan.host import EncryptionInfo
from pyVmomi.vim.vsan.host import RemoteVsanServerClusterConfig
from pyVmomi.vim.vsan.host import ServerClusterUnicastConfig

class ConfigInfoEx(ConfigInfo):
   encryptionInfo: Optional[EncryptionInfo] = None
   dataEfficiencyInfo: Optional[DataEfficiencyConfig] = None
   resyncIopsLimitInfo: Optional[ResyncIopsInfo] = None
   extendedConfig: Optional[VsanExtendedConfig] = None
   datastoreInfo: Optional[DatastoreConfig] = None
   unmapConfig: Optional[VsanUnmapConfig] = None
   witnessHostConfig: list[WitnessHostConfig] = []
   internalExtendedConfig: Optional[VsanInternalExtendedConfig] = None
   metricsConfig: Optional[MetricsConfig] = None
   unicastConfig: Optional[ServerClusterUnicastConfig] = None
   rdmaConfig: Optional[RdmaConfig] = None
   dataInTransitEncryptionInfo: Optional[DataInTransitEncryptionInfo] = None
   mode: Optional[str] = None
   serverClusterConfigs: list[RemoteVsanServerClusterConfig] = []
   snapServiceConfig: Optional[SnapServiceConfig] = None
   deconvergedNetConfig: Optional[VsanDeconvergedNetConfig] = None



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import Optional

from pyVmomi.vmodl import DynamicData

from pyVmomi.vim.net import DhcpConfigSpec

class IpConfigSpec(DynamicData):
   class IpAddressSpec(DynamicData):
      ipAddress: str
      prefixLength: int
      operation: str

   ipAddress: list[IpAddressSpec] = []
   dhcp: Optional[DhcpConfigSpec] = None
   autoConfigurationEnabled: Optional[bool] = None



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import Optional

from pyVmomi.vmodl import MethodFault

from pyVmomi.eam.issue.cluster.agent import AgentIssue

class OvfInvalidProperty(AgentIssue):
   error: list[MethodFault] = []



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import ClassVar

from pyVmomi.VmomiSupport import Enum

from pyVmomi.vmodl import DynamicData

class HealthUpdateInfo(DynamicData):
   class ComponentType(Enum):
      Memory: ClassVar['ComponentType'] = 'Memory'
      Power: ClassVar['ComponentType'] = 'Power'
      Fan: ClassVar['ComponentType'] = 'Fan'
      Network: ClassVar['ComponentType'] = 'Network'
      Storage: ClassVar['ComponentType'] = 'Storage'

   id: str
   componentType: str
   description: str



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from datetime import datetime

from typing import Optional

from pyVmomi.vmodl import DynamicData

from pyVmomi.pbm.profile import ProfileId

class Profile(DynamicData):
   profileId: ProfileId
   name: str
   description: Optional[str] = None
   creationTime: datetime
   createdBy: str
   lastUpdatedTime: datetime
   lastUpdatedBy: str



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import NoReturn
from typing import Optional

from pyVmomi.VmomiSupport import ManagedObject

from pyVmomi.vim import Extension
from pyVmomi.vim import ManagedEntity

from pyVmomi.vmodl import DynamicData

class ExtensionManager(ManagedObject):
   class IpAllocationUsage(DynamicData):
      extensionKey: str
      numAddresses: int

   @property
   def extensionList(self) -> list[Extension]: ...

   def UnregisterExtension(self, extensionKey: str) -> NoReturn: ...
   def FindExtension(self, extensionKey: str) -> Optional[Extension]: ...
   def RegisterExtension(self, extension: Extension) -> NoReturn: ...
   def UpdateExtension(self, extension: Extension) -> NoReturn: ...
   def GetPublicKey(self) -> str: ...
   def SetPublicKey(self, extensionKey: str, publicKey: str) -> NoReturn: ...
   def SetCertificate(self, extensionKey: str, certificatePem: Optional[str]) -> NoReturn: ...
   def SetServiceAccount(self, extensionKey: str, serviceAccount: str) -> NoReturn: ...
   def QueryManagedBy(self, extensionKey: str) -> list[ManagedEntity]: ...
   def QueryExtensionIpAllocationUsage(self, extensionKeys: list[str]) -> list[IpAllocationUsage]: ...



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import Optional

from pyVmomi.VmomiSupport import long

from pyVmomi.vmodl import DynamicData

class PortStatistics(DynamicData):
   packetsInMulticast: long
   packetsOutMulticast: long
   bytesInMulticast: long
   bytesOutMulticast: long
   packetsInUnicast: long
   packetsOutUnicast: long
   bytesInUnicast: long
   bytesOutUnicast: long
   packetsInBroadcast: long
   packetsOutBroadcast: long
   bytesInBroadcast: long
   bytesOutBroadcast: long
   packetsInDropped: long
   packetsOutDropped: long
   packetsInException: long
   packetsOutException: long
   bytesInFromPnic: Optional[long] = None
   bytesOutToPnic: Optional[long] = None



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from datetime import datetime

from typing import ClassVar
from typing import NoReturn
from typing import Optional

from pyVmomi.VmomiSupport import Enum

from pyVmomi.vim import HostSystem
from pyVmomi.vim import KeyValue
from pyVmomi.vim import ManagedEntity
from pyVmomi.vim import Task
from pyVmomi.vim import VirtualMachine

from pyVmomi.vmodl import DynamicData

from pyVmomi.vim.encryption import CryptoKeyId
from pyVmomi.vim.encryption import CryptoKeyResult
from pyVmomi.vim.encryption import CryptoManager
from pyVmomi.vim.encryption import KeyProviderId
from pyVmomi.vim.encryption import KmipClusterInfo
from pyVmomi.vim.encryption import KmipServerInfo
from pyVmomi.vim.encryption import KmipServerSpec

class CryptoManagerKmip(CryptoManager):
   class CertificateInfo(DynamicData):
      subject: str
      issuer: str
      serialNumber: str
      notBefore: datetime
      notAfter: datetime
      fingerprint: str
      checkTime: datetime
      secondsSinceValid: Optional[int] = None
      secondsBeforeExpire: Optional[int] = None

   class ServerStatus(DynamicData):
      name: str
      status: ManagedEntity.Status
      connectionStatus: str
      certInfo: Optional[CertificateInfo] = None
      clientTrustServer: Optional[bool] = None
      serverTrustClient: Optional[bool] = None

   class ClusterStatus(DynamicData):
      clusterId: KeyProviderId
      overallStatus: Optional[ManagedEntity.Status] = None
      managementType: Optional[str] = None
      servers: list[ServerStatus] = []
      clientCertInfo: Optional[CertificateInfo] = None

   class GenerateKeySpec(DynamicData):
      keyType: Optional[str] = None

   class ServerCertInfo(DynamicData):
      certificate: str
      certInfo: Optional[CertificateInfo] = None
      clientTrustServer: Optional[bool] = None

   class CertSignRequest(DynamicData):
      commonName: Optional[str] = None
      organization: Optional[str] = None
      organizationUnit: Optional[str] = None
      locality: Optional[str] = None
      state: Optional[str] = None
      country: Optional[str] = None
      email: Optional[str] = None

   class CryptoKeyStatus(DynamicData):
      class KeyUnavailableReason(Enum):
         KeyStateMissingInCache: ClassVar['KeyUnavailableReason'] = 'KeyStateMissingInCache'
         KeyStateClusterInvalid: ClassVar['KeyUnavailableReason'] = 'KeyStateClusterInvalid'
         KeyStateClusterUnreachable: ClassVar['KeyUnavailableReason'] = 'KeyStateClusterUnreachable'
         KeyStateMissingInKMS: ClassVar['KeyUnavailableReason'] = 'KeyStateMissingInKMS'
         KeyStateNotActiveOrEnabled: ClassVar['KeyUnavailableReason'] = 'KeyStateNotActiveOrEnabled'
         KeyStateManagedByTrustAuthority: ClassVar['KeyUnavailableReason'] = 'KeyStateManagedByTrustAuthority'
         KeyStateManagedByNKP: ClassVar['KeyUnavailableReason'] = 'KeyStateManagedByNKP'
         NoPermissionToAccessKeyProvider: ClassVar['KeyUnavailableReason'] = 'NoPermissionToAccessKeyProvider'
         WrappingKeyMissingInKMS: ClassVar['KeyUnavailableReason'] = 'WrappingKeyMissingInKMS'
         WrappingKeyNotActiveOrEnabled: ClassVar['KeyUnavailableReason'] = 'WrappingKeyNotActiveOrEnabled'

      class KeyInfo(DynamicData):
         keyId: str

      class WrappingKeyIdKeyInfo(CryptoKeyStatus.KeyInfo):
         configuredTime: Optional[datetime] = None

      class WrappingRotationIntervalKeyInfo(CryptoKeyStatus.KeyInfo):
         createTime: Optional[datetime] = None
         rotateTime: Optional[datetime] = None

      keyId: CryptoKeyId
      keyAvailable: Optional[bool] = None
      reason: Optional[str] = None
      keyInfo: Optional[KeyInfo] = None
      encryptedVMs: list[VirtualMachine] = []
      affectedHosts: list[HostSystem] = []
      referencedByTags: list[str] = []

   class CustomAttributeSpec(DynamicData):
      attributes: list[KeyValue] = []

   @property
   def kmipServers(self) -> list[KmipClusterInfo]: ...

   def RegisterKmipServer(self, server: KmipServerSpec) -> NoReturn: ...
   def MarkDefault(self, clusterId: KeyProviderId) -> NoReturn: ...
   def UpdateKmipServer(self, server: KmipServerSpec) -> NoReturn: ...
   def RemoveKmipServer(self, clusterId: KeyProviderId, serverName: str) -> NoReturn: ...
   def ListKmipServers(self, limit: Optional[int]) -> list[KmipClusterInfo]: ...
   def RetrieveKmipServersStatus(self, clusters: list[KmipClusterInfo]) -> Task: ...
   def GenerateKey(self, keyProvider: Optional[KeyProviderId], spec: Optional[CustomAttributeSpec], keySpec: Optional[GenerateKeySpec]) -> CryptoKeyResult: ...
   def RetrieveKmipServerCert(self, keyProvider: KeyProviderId, server: KmipServerInfo) -> ServerCertInfo: ...
   def UploadKmipServerCert(self, cluster: KeyProviderId, certificate: str) -> NoReturn: ...
   def GenerateSelfSignedClientCert(self, cluster: KeyProviderId, request: Optional[CertSignRequest]) -> str: ...
   def GenerateClientCsr(self, cluster: KeyProviderId, request: Optional[CertSignRequest]) -> str: ...
   def RetrieveSelfSignedClientCert(self, cluster: KeyProviderId) -> str: ...
   def RetrieveClientCsr(self, cluster: KeyProviderId) -> str: ...
   def RetrieveClientCert(self, cluster: KeyProviderId) -> str: ...
   def UpdateSelfSignedClientCert(self, cluster: KeyProviderId, certificate: str) -> NoReturn: ...
   def UpdateKmsSignedCsrClientCert(self, cluster: KeyProviderId, certificate: str) -> NoReturn: ...
   def UploadClientCert(self, cluster: KeyProviderId, certificate: str, privateKey: str) -> NoReturn: ...
   def IsKmsClusterActive(self, cluster: Optional[KeyProviderId]) -> bool: ...
   def SetDefaultKmsCluster(self, entity: Optional[ManagedEntity], clusterId: Optional[KeyProviderId]) -> NoReturn: ...
   def GetDefaultKmsCluster(self, entity: Optional[ManagedEntity], defaultsToParent: Optional[bool]) -> Optional[KeyProviderId]: ...
   def QueryCryptoKeyStatus(self, keyIds: list[CryptoKeyId], checkKeyBitMap: int) -> list[CryptoKeyStatus]: ...
   def RegisterKmsCluster(self, clusterId: KeyProviderId, managementType: Optional[str]) -> NoReturn: ...
   def UnregisterKmsCluster(self, clusterId: KeyProviderId) -> NoReturn: ...
   def ListKmsClusters(self, includeKmsServers: Optional[bool], managementTypeFilter: Optional[int], statusFilter: Optional[int]) -> list[KmipClusterInfo]: ...
   def SetKeyCustomAttributes(self, keyId: CryptoKeyId, spec: CustomAttributeSpec) -> CryptoKeyResult: ...



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import NoReturn
from typing import Optional

from pyVmomi.VmomiSupport import ManagedObject

from pyVmomi.vim import ClusterComputeResource
from pyVmomi.vim import ComputeResource
from pyVmomi.vim import Task

from pyVmomi.vim.cluster import VsanClusterHealthGroup
from pyVmomi.vim.cluster import VsanObjectInformation
from pyVmomi.vim.cluster import VsanPerfDiagnoseQuerySpec
from pyVmomi.vim.cluster import VsanPerfDiagnosticException
from pyVmomi.vim.cluster import VsanPerfDiagnosticResult
from pyVmomi.vim.cluster import VsanPerfEntityMetricCSV
from pyVmomi.vim.cluster import VsanPerfEntityType
from pyVmomi.vim.cluster import VsanPerfHotspotEntitiesMetrics
from pyVmomi.vim.cluster import VsanPerfHotspotQuerySpec
from pyVmomi.vim.cluster import VsanPerfNodeInformation
from pyVmomi.vim.cluster import VsanPerfQuerySpec
from pyVmomi.vim.cluster import VsanPerfTimeRange
from pyVmomi.vim.cluster import VsanPerfTimeRangeQuerySpec
from pyVmomi.vim.cluster import VsanPerfTopQuerySpec
from pyVmomi.vim.cluster import VsanRemoteClusterQuerySpec

from pyVmomi.vim.vm import ProfileSpec

class VsanPerformanceManager(ManagedObject):
   def QueryVsanPerfTopEntities(self, cluster: Optional[ClusterComputeResource], querySpec: VsanPerfTopQuerySpec) -> list[VsanPerfEntityMetricCSV]: ...
   def QueryVsanPerfHotspotEntities(self, cluster: Optional[ClusterComputeResource], querySpec: VsanPerfHotspotQuerySpec) -> list[VsanPerfHotspotEntitiesMetrics]: ...
   def VsanPerfDiagnose(self, perfDiagnoseQuery: VsanPerfDiagnoseQuerySpec, cluster: Optional[ComputeResource]) -> list[VsanPerfDiagnosticResult]: ...
   def VsanPerfDiagnoseTask(self, perfDiagnoseQuery: VsanPerfDiagnoseQuerySpec, cluster: Optional[ComputeResource]) -> Task: ...
   def GetVsanPerfDiagnosisResult(self, task: Task, cluster: Optional[ComputeResource]) -> list[VsanPerfDiagnosticResult]: ...
   def QueryVsanPerf(self, querySpecs: list[VsanPerfQuerySpec], cluster: Optional[ComputeResource]) -> list[VsanPerfEntityMetricCSV]: ...
   def QueryNodeInformation(self, cluster: Optional[ComputeResource]) -> list[VsanPerfNodeInformation]: ...
   def CreateStatsObject(self, cluster: Optional[ComputeResource], profile: Optional[ProfileSpec]) -> str: ...
   def CreateStatsObjectTask(self, cluster: Optional[ComputeResource], profile: Optional[ProfileSpec]) -> Task: ...
   def DeleteStatsObject(self, cluster: Optional[ComputeResource]) -> bool: ...
   def DeleteStatsObjectTask(self, cluster: Optional[ComputeResource]) -> Task: ...
   def SetStatsObjectPolicy(self, cluster: Optional[ComputeResource], profile: Optional[ProfileSpec]) -> bool: ...
   def QueryStatsObjectInformation(self, cluster: Optional[ComputeResource]) -> VsanObjectInformation: ...
   def QueryClusterHealth(self, cluster: ClusterComputeResource) -> list[VsanClusterHealthGroup]: ...
   def QueryTimeRanges(self, cluster: Optional[ClusterComputeResource], querySpec: VsanPerfTimeRangeQuerySpec) -> list[VsanPerfTimeRange]: ...
   def SaveTimeRanges(self, cluster: Optional[ClusterComputeResource], timeRanges: list[VsanPerfTimeRange]) -> NoReturn: ...
   def DeleteTimeRange(self, cluster: Optional[ClusterComputeResource], name: str) -> NoReturn: ...
   def ToggleVerboseMode(self, cluster: Optional[ClusterComputeResource], verboseMode: bool) -> NoReturn: ...
   def GetSupportedEntityTypes(self) -> list[VsanPerfEntityType]: ...
   def GetSupportedDiagnosticExceptions(self) -> list[VsanPerfDiagnosticException]: ...
   def GetAggregatedEntityTypes(self) -> list[VsanPerfEntityType]: ...
   def QueryRemoteServerClusters(self, cluster: Optional[ClusterComputeResource], querySpec: Optional[VsanRemoteClusterQuerySpec]) -> list[str]: ...



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import ClassVar

from pyVmomi.VmomiSupport import Enum

from pyVmomi.vim.option import ChoiceOption

from pyVmomi.vim.vm.device import VirtualDeviceOption

class VirtualPointingDeviceOption(VirtualDeviceOption):
   class DeviceBackingOption(VirtualDeviceOption.DeviceBackingOption):
      class HostPointingDeviceChoice(Enum):
         autodetect: ClassVar['HostPointingDeviceChoice'] = 'autodetect'
         intellimouseExplorer: ClassVar['HostPointingDeviceChoice'] = 'intellimouseExplorer'
         intellimousePs2: ClassVar['HostPointingDeviceChoice'] = 'intellimousePs2'
         logitechMouseman: ClassVar['HostPointingDeviceChoice'] = 'logitechMouseman'
         microsoft_serial: ClassVar['HostPointingDeviceChoice'] = 'microsoft_serial'
         mouseSystems: ClassVar['HostPointingDeviceChoice'] = 'mouseSystems'
         mousemanSerial: ClassVar['HostPointingDeviceChoice'] = 'mousemanSerial'
         ps2: ClassVar['HostPointingDeviceChoice'] = 'ps2'

      hostPointingDevice: ChoiceOption



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from datetime import datetime

from typing import Optional

from pyVmomi.vmodl import DynamicData

class QueryPointInTimeReplicaParam(DynamicData):
   class ReplicaQueryIntervalParam(DynamicData):
      fromDate: Optional[datetime] = None
      toDate: Optional[datetime] = None
      number: Optional[int] = None

   replicaTimeQueryParam: Optional[ReplicaQueryIntervalParam] = None
   pitName: Optional[str] = None
   tags: list[str] = []
   preferDetails: Optional[bool] = None



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import Optional

from pyVmomi.vmodl import DynamicData

from pyVmomi.vim.vm import ProfileSpec

class ProfileDetails(DynamicData):
   class DiskProfileDetails(DynamicData):
      diskId: int
      profile: list[ProfileSpec] = []

   profile: list[ProfileSpec] = []
   diskProfileDetails: list[DiskProfileDetails] = []



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import ClassVar
from typing import NoReturn
from typing import Optional

from pyVmomi.VmomiSupport import Enum
from pyVmomi.VmomiSupport import ManagedObject
from pyVmomi.VmomiSupport import long

from pyVmomi.vim import Datacenter
from pyVmomi.vim import Task

from pyVmomi.vmodl import DynamicData

from pyVmomi.vim.encryption import CryptoSpec

from pyVmomi.vim.host import DiskDimensions

from pyVmomi.vim.vm import ProfileSpec

class VirtualDiskManager(ManagedObject):
   class VirtualDiskType(Enum):
      preallocated: ClassVar['VirtualDiskType'] = 'preallocated'
      thin: ClassVar['VirtualDiskType'] = 'thin'
      seSparse: ClassVar['VirtualDiskType'] = 'seSparse'
      rdm: ClassVar['VirtualDiskType'] = 'rdm'
      rdmp: ClassVar['VirtualDiskType'] = 'rdmp'
      raw: ClassVar['VirtualDiskType'] = 'raw'
      delta: ClassVar['VirtualDiskType'] = 'delta'
      sparse2Gb: ClassVar['VirtualDiskType'] = 'sparse2Gb'
      thick2Gb: ClassVar['VirtualDiskType'] = 'thick2Gb'
      eagerZeroedThick: ClassVar['VirtualDiskType'] = 'eagerZeroedThick'
      sparseMonolithic: ClassVar['VirtualDiskType'] = 'sparseMonolithic'
      flatMonolithic: ClassVar['VirtualDiskType'] = 'flatMonolithic'
      thick: ClassVar['VirtualDiskType'] = 'thick'

   class VirtualDiskAdapterType(Enum):
      ide: ClassVar['VirtualDiskAdapterType'] = 'ide'
      busLogic: ClassVar['VirtualDiskAdapterType'] = 'busLogic'
      lsiLogic: ClassVar['VirtualDiskAdapterType'] = 'lsiLogic'

   class VirtualDiskSpec(DynamicData):
      diskType: str
      adapterType: str

   class FileBackedVirtualDiskSpec(VirtualDiskSpec):
      capacityKb: long
      profile: list[ProfileSpec] = []
      crypto: Optional[CryptoSpec] = None
      sectorFormat: Optional[str] = None

   class SeSparseVirtualDiskSpec(FileBackedVirtualDiskSpec):
      grainSizeKb: Optional[int] = None

   class DeviceBackedVirtualDiskSpec(VirtualDiskSpec):
      device: str

   def CreateVirtualDisk(self, name: str, datacenter: Optional[Datacenter], spec: VirtualDiskSpec) -> Task: ...
   def DeleteVirtualDisk(self, name: str, datacenter: Optional[Datacenter]) -> Task: ...
   def MoveVirtualDisk(self, sourceName: str, sourceDatacenter: Optional[Datacenter], destName: str, destDatacenter: Optional[Datacenter], force: Optional[bool], profile: list[ProfileSpec]) -> Task: ...
   def CopyVirtualDisk(self, sourceName: str, sourceDatacenter: Optional[Datacenter], destName: str, destDatacenter: Optional[Datacenter], destSpec: Optional[VirtualDiskSpec], force: Optional[bool]) -> Task: ...
   def ExtendVirtualDisk(self, name: str, datacenter: Optional[Datacenter], newCapacityKb: long, eagerZero: Optional[bool]) -> Task: ...
   def QueryVirtualDiskFragmentation(self, name: str, datacenter: Optional[Datacenter]) -> int: ...
   def DefragmentVirtualDisk(self, name: str, datacenter: Optional[Datacenter]) -> Task: ...
   def ShrinkVirtualDisk(self, name: str, datacenter: Optional[Datacenter], copy: Optional[bool]) -> Task: ...
   def InflateVirtualDisk(self, name: str, datacenter: Optional[Datacenter]) -> Task: ...
   def EagerZeroVirtualDisk(self, name: str, datacenter: Optional[Datacenter]) -> Task: ...
   def ZeroFillVirtualDisk(self, name: str, datacenter: Optional[Datacenter]) -> Task: ...
   def SetVirtualDiskUuid(self, name: str, datacenter: Optional[Datacenter], uuid: str) -> NoReturn: ...
   def QueryVirtualDiskUuid(self, name: str, datacenter: Optional[Datacenter]) -> str: ...
   def QueryVirtualDiskGeometry(self, name: str, datacenter: Optional[Datacenter]) -> DiskDimensions.Chs: ...
   def ImportUnmanagedSnapshot(self, vdisk: str, datacenter: Optional[Datacenter], vvolId: str) -> NoReturn: ...
   def ReleaseManagedSnapshot(self, vdisk: str, datacenter: Optional[Datacenter]) -> NoReturn: ...



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from datetime import datetime

from typing import ClassVar
from typing import Optional

from pyVmomi.VmomiSupport import Enum
from pyVmomi.VmomiSupport import long

from pyVmomi.vim import Datastore
from pyVmomi.vim import KeyValue

from pyVmomi.vmodl import DynamicData

from pyVmomi.vim.encryption import CryptoKeyId

from pyVmomi.vim.vslm import ID
from pyVmomi.vim.vslm import VClockInfo

class BaseConfigInfo(DynamicData):
   class BackingInfo(DynamicData):
      datastore: Datastore

   class FileBackingInfo(BackingInfo):
      filePath: str
      backingObjectId: Optional[str] = None
      parent: Optional[FileBackingInfo] = None
      deltaSizeInMB: Optional[long] = None
      keyId: Optional[CryptoKeyId] = None

   class DiskFileBackingInfo(FileBackingInfo):
      class ProvisioningType(Enum):
         thin: ClassVar['ProvisioningType'] = 'thin'
         eagerZeroedThick: ClassVar['ProvisioningType'] = 'eagerZeroedThick'
         lazyZeroedThick: ClassVar['ProvisioningType'] = 'lazyZeroedThick'

      provisioningType: str

   class RawDiskMappingBackingInfo(FileBackingInfo):
      lunUuid: str
      compatibilityMode: str

   id: ID
   name: str
   createTime: datetime
   keepAfterDeleteVm: Optional[bool] = None
   relocationDisabled: Optional[bool] = None
   nativeSnapshotSupported: Optional[bool] = None
   changedBlockTrackingEnabled: Optional[bool] = None
   backing: BackingInfo
   metadata: list[KeyValue] = []
   vclock: Optional[VClockInfo] = None
   iofilter: list[str] = []
